#############################################################################
# !make
#
# !Makefile name: MOD_PR11A.mk
#
# !Description: This is the makefile for MOD_PR11.exe, the MODIS
#              Level 2 and Level 3 Land Surface Temperature process
#
# !Variables		
#   INC           Include directories
#   LIB           Library directories
#   OBJ           Object files
#   TARGET        Target executable
#   ADD_CFLAGS    Additional compiler settings, specified in this make
#   INC_FILES     Additional include files
#
# !Environment variables
#   API_INC       Include directory of MAPI set by the script
#   PGSINC        Include directory of PGS toolkit set by the script
#   HDFINC        Include directory of HDF set by the script
#   HDFEOS_INC    Include directory of HDFEOS set by the script
#   API_LIB       Library of MAPI set by the script
#   PGSLIB        Library of PGS toolkit set by the script
#   HDFLIB        Library of HDF set by the script
#   HDFEOS_LIB    Library of HDFEOS set by the script
#   CC		  Compiler environment variable
#   CFLAGS        Additional compiler settings in the environment
#
# !Team-unique Header:
#   MODIS Land Science Team for the National 
#   Aeronautics and Space Administration, Goddard Space Flight 
#   Center, under NASA Task 92-012-05.
#
# !Revision History:
#    Rev 1.2     Carol Collins    09/04/2001
#                  Removed cakecut.o from list of source files.  No longer needed.
#    Rev 1.0.1   Carol Collins    06/01/2001
#                  Modified make file to be consistent with other Land make file
#                  format 
#    Rev 1.0     Z. Wan          05/25/01 
#    Original development
#
# !END
#############################################################################

TARGET  = MOD_PR11A.exe
MKFILE  = MOD_PR11A.mk

target :
	case "$(BRAND)" in \
         dec ) \
           $(MAKE) $(TARGET) -f $(MKFILE) \
		   CFLAGS=" "\
                   ADD_CFLAGS="-g3 -std1"\
           ;;\
         sgi32 | sgi64 ) \
           $(MAKE) $(TARGET) -f $(MKFILE) \
                   ADD_CFLAGS="-O3 -OPT:Olimit=6000"\
           ;;\
         linux ) \
           $(MAKE) $(TARGET) -f $(MKFILE) \
                   ADD_CFLAGS="-O3 -ffloat-store -fwritable-strings" \
           ;; \
         * ) \
         echo " ERROR: Environment variable BRAND (set to \"$(BRAND)\") not required." >&2 ; \
         exit 1 ;; \
	esac 

INC   = -I$(PGSINC) -I$(HDFINC) -I$(HDFEOS_INC) -I$(API_INC)  

LIB =   -L$(HDFEOS_LIB) -lhdfeos -lGctp \
        -L$(HDFLIB) -lmfhdf -ldf -lz  \
        -L$(PGSLIB) -lPGSTK \
        -L$(API_LIB) -lmapi \
        -lm

OBJ     = mod11_lst2A1.o \
          smf.o     \
	  lbin_lst.o \
          timea.o 

INC_FILES       = band_emis.h bit_flag.h cakecut.h day_nit_lut.h \
                        lbin_lst.h lhdf.h lst_1dy_data.h lst_coef.h \
                        mod.fm1.rad7.h mod.pfm-vC.rad7.h obsgrid_lst.h \
			pntr_lst.h smfio.h update_for_lst.h

$(TARGET): $(OBJ)
	$(CC) $(CFLAGS) $(ADD_CFLAGS) -o $(TARGET) $(OBJ) $(LIB)

clean:
	rm -f *.o core

#
# Rules
#
$(OBJ): $(INC_FILES)
.c.o:
	$(CC) $(CFLAGS) $(ADD_CFLAGS) $(INC) -c $< -o $@
