#############################################################################
# !make
#
# !Makefile name: MOD_PR11B1S.mk
#
# !Description: This is the makefile for MOD_PR11.exe, the MODIS
#              Level 2 and Level 3 Land Surface Temperature process
#
# !Variables		
#   INC           Include directories
#   LIB           Library directories
#   OBJ           Object files
#   TARGET        Target executable
#   ADD_CFLAGS    Additional compiler settings, specified in this make
#   INC_FILES     Additional include files
#
# !Environment variables
#   API_INC       Include directory of MAPI set by the script
#   PGSINC        Include directory of PGS toolkit set by the script
#   HDFINC        Include directory of HDF set by the script
#   HDFEOS_INC    Include directory of HDFEOS set by the script
#   API_LIB       Library of MAPI set by the script
#   PGSLIB        Library of PGS toolkit set by the script
#   HDFLIB        Library of HDF set by the script
#   HDFEOS_LIB    Library of HDFEOS set by the script
#   CC		  Compiler environment variable
#   CFLAGS        Additional compiler settings in the environment
#
# !Team-unique Header:
#   MODIS Land Science Team for the National 
#   Aeronautics and Space Administration, Goddard Space Flight 
#   Center, under NASA Task 92-012-05.
#
# !Revision History:
#    Rev 1.0     G. Fireman	09/26/05 
#
# !END
#############################################################################

TARGET  = MOD_PR11B1S.exe
MKFILE  = MOD_PR11B1S.mk

target :
	case "$(BRAND)" in \
         dec ) \
           $(MAKE) $(TARGET) -f $(MKFILE) \
		   CFLAGS=" "\
                   ADD_CFLAGS="-g3 -std1"\
           ;;\
         sgi32 | sgi64 ) \
           $(MAKE) $(TARGET) -f $(MKFILE) \
                   ADD_CFLAGS="-O3"\
           ;;\
         linux ) \
           $(MAKE) $(TARGET) -f $(MKFILE) \
                   ADD_CFLAGS="-O3 -ffloat-store -fwritable-strings" \
           ;; \
         * ) \
         echo " ERROR: Environment variable BRAND (set to \"$(BRAND)\") not required." >&2 ; \
         exit 1 ;; \
	esac 

INC   = -I$(PGSINC) -I$(HDFINC) -I$(HDFEOS_INC) -I$(API_INC)  

LIB =   -L$(API_LIB) -lmapi \
        -L$(HDFLIB) -lmfhdf -ldf -lz \
        -L$(PGSLIB) -lPGSTK -lm

OBJ     = mod11b1_cldscreen.o \
          smf.o  \
          timea.o

INC_FILES       = bit_flag.h lst_1dy_data.h

$(TARGET): $(OBJ)
	$(CC) $(CFLAGS) $(ADD_CFLAGS) -o $(TARGET) $(OBJ) $(LIB)

clean:
	rm -f *.o core

#
# Rules
#
$(OBJ): $(INC_FILES)
.c.o:
	$(CC) $(CFLAGS) $(ADD_CFLAGS) $(INC) -c $< -o $@
