/* start of band_emis.h */

#ifndef band_emis_h
#define band_emis_h

/*****************************************************************************
!C-INC

!Description:

  Header file for prototype band emissivity database of land-surface materials.

!Input Parameters: None

!Output Parameters: None
  
$Log: band_emis.h, v $
 *
 * Revision V2.1  1999/12/29  15:10:40  wan
 * corresponds to Land_Cover_Type_1 in version 3 of the UM land-cover product
 *
 * Revision V2.0  1997/11/01  11:40:17  wan
 * add the relationship with landcover types
 *
 * Revision B3.1  1995/08/01  11:02:41  wan
 * Initial revision
 *
$Id: band_emis.h, v V2.0 1997/11/01 11:40:17 wan Exp wan $

!Revision History:

!Team-unique Header:
  This software has been created by MODIS Science Team member Zhengming Wan
  for the National Aeronautics and Space Administration, Goddard Space
  Flight Center, under contract NAS5-31370.

!References and Credits:

	Written by Zhengming Wan
	ICESS
	UCSB
	Santa Barbara, CA 93106

	wan@icess.ucsb.edu

	W. Snyder, Z. Wan, Y. Zhang, and Y.-Z. Feng, "Classification-based
	emissivity for the EOS/MODIS land surface temperature algorithm",
	Remote Sens. Environ., in press, 1997.

!Design Notes:

!END
*****************************************************************************/

typedef struct	_band_emis_db {
	double	e31, e32;	/* band emissivities for modis bands 31 & 32 */
	double	ang_e31, ang_e32;	/* angular coefficients for e31 & e32
					   at view angle > 42.3 degree
					   e31(v) = e31 + ang_e31 *
					   		  [rad(v) - rad(42.3)]
					   similarly for e32(v) */
	double	rms_m_em, rms_d_em;	/* rms of mean and difference
					   emissivities used in split-window
					   method */

}	_BAND_EMIS_DB;

#define N_LANDCOV_TYPES 20
#define N_EMISS_CLASSES 19
#define N_CLASS_STATES   2

int32	_landcov_to_emisclass[N_LANDCOV_TYPES+1][N_CLASS_STATES] = {

	 1,  1,		/* water 0 */
	 4,  4,		/* evergreen needleleaf forest 1 */
	 5,  5,		/* evergreen broadleaf forest 2 */
	 4,  8,		/* (green & senescent) deciduous needleleaf forest 3 */
	 5, 12,		/* (green & senescent) deciduous broadleaf forest 4 */
	 5, 12,		/* (green & senescent) mixed forest 5 */
	 7, 11,		/* (green & senescent) closed shrublands 6 */
	13, 14,		/* (green & senescent) open shrublands 7 */
	 6,  9,		/* (green & senescent) woody savannas 8 */
	 7, 11,		/* (green & senescent) savannas 9 */
	 7, 11,		/* (green & senescent) grasslands 10 */
	 1,  1,		/* permanent wetlands 11 */
	 7, 10,		/* (green & senescent) croplands 12 */
	15, 16,		/* (green & senescent) urban and built-up 13 */
	 7, 11,		/* (green & senescent) cropland and mosaics 14 */
	 2,  3,	     /* (dry/fine snow & med/coarse snow/ice) snow and ice 15 */
	17, 17, 	/* bare soil and rocks 16 */
	 0,  0,         /* unclassified 17, use average values */
	18, 18,         /* coastline 18 */
	 1,  1,         /* ocean 19 */
	 0,  0          /* filled & unused */

};

_BAND_EMIS_DB	mod_band_emis_db[N_EMISS_CLASSES] = {

0.978,  0.981, -0.0022, -0.0035, 0.0085, 0.0034, /*  0 default surface 
						   (simple average of the
						    emis classes 1-16) */

0.992,	0.988, -0.0268, -0.0483, 0.0049, 0.0024, /*  1 water surface */

0.993,	0.990,  0.0000,  0.0000, 0.0023, 0.0006, /*  2 dry/fine snow */

0.984,  0.971, -0.0027, -0.0107, 0.0069, 0.0059, /*  3 med/coarse snow & ice */

0.989,	0.991, -0.0027, -0.0027, 0.0029, 0.0005, /*  4 gr. ndle. forest */

0.987,	0.990, -0.0027, -0.0027, 0.0035, 0.0015, /*  5 gr. bdlf. forest */

0.988,	0.991,  0.0027,  0.0027, 0.0039, 0.0013, /*  6 gr. woody savanna */

0.987,	0.991,  0.0027,  0.0000, 0.0034, 0.0014, /*  7 gr. grass savanna */

0.986,	0.988, -0.0027,  0.0000, 0.0040, 0.0011, /*  8 sn. ndle forest */

0.975,	0.978,  0.0000,  0.0027, 0.0095, 0.0015, /*  9 sn. woody savanna */

0.977,	0.982, -0.0027,  0.0000, 0.0071, 0.0022, /* 10 org. bare soil */

0.973,	0.975,  0.0000,  0.0000, 0.0115, 0.0021, /* 11 sn. grass savanna */

0.968,	0.971, -0.0054, -0.0054, 0.0109, 0.0038, /* 12 sn. bdlf forest */

0.972,	0.976,  0.0027,  0.0027, 0.0134, 0.0042, /* 13 gr. sparse shrubs */

0.970,	0.975,  0.0027,  0.0027, 0.0132, 0.0044, /* 14 sn. sparse shrubs */

0.970,	0.976,  0.0,     0.0,    0.0139, 0.0074, /* 15 gr. urban & built-up
				( 5% gr. ndle. forest + 10% gr. bdlf forest +
				 10% gr. grass savanna + 10% gr. sparse shrubs +
				 15% bare soils/rocks + 25% road & parking +
				 25% spec of 25 building material samples) */

0.966,	0.972,  0.0,     0.0,    0.0117, 0.0075, /* 16 sn. urban & built-up
				( 5% sn. ndle. forest + 10% sn. bdlf forest +
				 10% sn. grass savanna + 10% sn. sparse shrubs +
				 15% bare soils/rocks + 25% road & parking +
				 25% spec of 25 building material samples) */

0.965,	0.972,  0.0,     0.0,    0.0148, 0.0063, /* 17 arid bare soil & rocks */

0.9864,	0.9852, -0.017, -0.0304,  0.0063, 0.0028 /* 18 coastline */
						 /* 60% water + 40% averaged */

};

#endif		/* end of band_emis.h */
