/* start of bit_flag.h */

#ifndef	bit_flag_h
#define	bit_flag_h

/*****************************************************************************
!C-INC

!Description:

  Header file for bit flags used in MOD11_L2 QC

!Input Parameters: None

!Output Parameters: None
  
$Log: bit_flag.h, v $
 *
 * Revision B3.1  1995/08/30  12:02:41  wan
 * Initial revision
 *
$Id: bit_flag.h, v B3.1 1995/08/30 26:02:41 wan Exp wan $

!Revision History:

!Team-unique Header:
  This software has been created by MODIS Science Team member Zhengming Wan
  for the National Aeronautics and Space Administration, Goddard Space
  Flight Center, under contract NAS5-31370.

!References and Credits:

	Written by Zhengming Wan
	ICESS
	UCSB
	Santa Barbara, CA 93106

	wan@icess.ucsb.edu

!Design Notes

!END
*****************************************************************************/


#define	PROC_BITS	03	/* processing flag (bits 00-01) */
				/* 00=Pixel produced, good quality, not
				      necessary to examine more detailed QA */
				/* 01=Pixel produced, unreliable or unquan-
				      tifiable quality, recommend examination
				      of more detailed QA */
				/* 10=Pixel not produced due to cloud effect */
				/* 11=Pixel not produced primarily due to
				      reasons other than cloud */

#define	DATA_QC_BITS 014	/* data quality flags (bits 02-03)*/
				/* 00 good */
				/* 01 missing pixel */
				/* 10 fairly calibrated */
				/* 11 poorly calibrated, no LST processing */

#define	CLOUD_BITS 060	/* cloud flags (bits 04-05) */
			/* 00 cloud free pixel */
			/* 01 only with thin cirrus */
			/* 10 fraction of sub-pixel clouds <= 2/16 */
			/* 11 TBD */

#define	LST_MODEL 0300	/* LST model number flags (bits 06-07) */
			/* 00 generalized split-window method */
			/* 01 day/night method */
			/* 10 high LST w/o atmospheric & emis corrections */
			/* 11 cirrus effects corrected */

#define	LST_QA_BITS 01400	/* LST consistency flags (bits 08-09) */
			/* 00 no multi-method comparison */
			/* 01 multi-method comparison done */
			/* 10 fair consistency */
			/* 11 good consistency */

#define	EM_FLAG	06000	/* emissivity flags (bits 10-11) */
			/* 00 inferred from land-cover type */
			/* 01 MODIS retrieved */
			/* 10 TBD */
			/* 11 default value used */

#define	EM_CHK	030000	/* emissivity quality flags (bits 12-13) */
			/* 00 emis quality not checked */
			/* 01 emis quality checked with land-cover type */
			/* 10 emis quality checked with NDVI */
			/* 11 emis view-angle dependence checked */

#define	EM_ERR	0140000	/* emissivity error flags (bits 14-15) */
				/* 00 error <= 0.01 */
				/* 01 error <= 0.02 */
				/* 10 error <= 0.04 */
				/* 11 error >  0.04 */

/* check, set a single bit at position i on or off */
#define CHK_BIT(x, i)      ( (x >> i) & 01 )
#define SET_BIT(x, i)      ( *x |= ( 01 << i ) )
#define OFF_BIT(x, i)      ( *x &= ~( 01 << i ) )

/* prototype functions to get and set bits in uint8 and uint16 */
uint8 u8getbits(uint8, int32, int32);
void  u8setbits(uint8 *, int32, int32, uint8);

uint16 u16getbits(uint16, int32, int32);
void   u16setbits(uint16 *, int32, int32, uint16);

#endif		/* end of bit_flag.h */
