/* start of land_tile_tbl.h */

#ifndef land_tile_tbl_h
#define land_tile_tbl_h

/*****************************************************************************
!C-INC

!Description:

  Header file for the land tile structure and relations.

!Input Parameters: None

!Output Parameters: None

!Revision History:

   $Log: land_tile_tbl.h, v $
 *
 * Revision V2.2.1  1999/12/27  22:57:25  wan
 * Combined with the at-launch version (version 3) of the UM land cover
 * (including 314 land tiles and 3 tiles with coastline grids)
 * N_LAND_TILE was changed to 317 from 326
 *
 * Revision V2.1.1  1999/09/17  09:14:01  wan
 * Add begin_seconds and end_seconds into struct _tile_pointer
 *
 * Revision V2.02  1997/11/14  11:32:53  wan
 * Add reg_id in _LAND_TILE_TBL
 *
 * Revision V2.01  1997/10/01  22:08:17  wan
 * Initial revision
 *
   $Id: land_tile_tbl.h, v V2.0 1997/10/11 22:08:17 wan Exp wan $

!Team-unique Header:
  This software has been created by MODIS Science Team member Zhengming Wan
  for the National Aeronautics and Space Administration, Goddard Space
  Flight Center, under contract NAS5-31370.

!References and Credits:

	Written by Zhengming Wan
	ICESS
	UCSB
	Santa Barbara, CA 93106

	wan@icess.ucsb.edu

	Robert Wolfe, MODIS Land Team Support Group,  provided the global
	land tile figure and the L2G library functions.
	John Townshend, University of Maryland, provided the IGBP type
	land-cover product.
	All these have been incorporated into the design of this header.

!Design Notes:

  1. The reg_id # of each land tile is the first number in every structure
     of land_tile_tbl[] below.
  2. For land tiles containing LST cal/val test sites, reg_id # is set to 1.
  3. The relation between geographic regions and the reg_id # is as follows:
	region				reg_id
     North America (Lat < 60 deg)	  2
     South America			  3
     Africa				  4
     Erope (Lat < 60 deg)	  	  5
     Middle East			  6
     Asia				  7
     Australia				  8
     Far East				  9
     Lat > 60 deg & Lon < 0 deg	  	 10
     Lat > 60 deg & Lon > 0 deg	  	 11
     Antarctica				 12
     islands				 13

!END
*****************************************************************************/

#define	N_LAND_TILE	317
#define	N_EDGE_PNTS	5
#define	N_VERT_TILE	18
#define	N_HORI_TILE	36

#define N_TILE_PNTRS    32

typedef struct {

	int16   iv;
	int16   ih;
	int16	scan_mode;
	int16   k_scan_start;
	int16   k_scan_end;
	int16   s_num;
	int16	l3_1km_exist;
	int16	l3_6km_exist;
	int32	update_exist;
	int32	i_tbd;
	float64	begin_seconds;
	float64	end_seconds;

} _tile_pointer;

int16	_land_tile_id[N_VERT_TILE][N_HORI_TILE] = {

/* h0  h1  h2  h3  h4  h5  h6  h7  h8  h9 h10 h11 h12 h13 h14 h15 h16 h17 or */
/*h18 h19 h20 h21 h22 h23 h24 h25 h26 h27 h28 h29 h30 h31 h32 h33 h34 h35 or */

/* v00 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,110,122,
 137,151, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,

/* v01 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 67, 79, 90,100,111,123,
 138,152,167,183,198,213, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,

/* v02 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, 38, 46, 56, 68, 80, 91,101,112,124,
 139,153,168,184,199,214,226,234,242, -1, -1, -1, -1, -1, -1, -1, -1, -1,

/* v03 */
  -1, -1, -1, -1, -1, -1, 24, 26, 30, 39, 47, 57, 69, 81, 92,102, -1,125,
 140,154,169,185,200,215,227,235,243,249,260,272, -1, -1, -1, -1, -1, -1,

/* v04 */
  -1, -1, -1, -1, -1, -1, -1, -1, 31, 40, 48, 58, 70, 82, 93, -1, -1,126,
 141,155,170,186,201,216,228,236,244,250,261, -1, -1, -1, -1, -1, -1, -1,

/* v05 */
  -1, -1, -1, -1, -1, -1, -1, 27, 32, 41, 49, 59, 71, -1, -1,103,113,127,
 142,156,171,187,202,217,229,237,245,251,262,273,282, -1, -1, -1, -1, -1,

/* v06 */
  -1, -1,  8, 13, -1, -1, -1, 28, 33, 42, 50, 60, -1, -1, -1, -1,114,128,
 143,157,172,188,203,218,230,238,246,252,263,274,283,291, -1, -1, -1, -1,

/* v07 */
  -1,  3, -1, 14, -1, -1, -1, 29, 34, 43, 51, 61, 72, -1, -1,104,115,129,
 144,158,173,189,204,219,231,239,247,253,264,275,284,292,299,305,310, -1,

/* v08 */
   0,  4,  9, -1, -1, -1, -1, -1, 35, 44, 52, 62, 73, 83, -1, -1,116,130,
 145,159,174,190,205,220, -1,240,248,254,265,276,285,293,300,306,311,314,

/* v09 */
   1,  5, 10, 15, 18, -1, -1, -1, 36, 45, 53, 63, 74, 84, 94, -1,117, -1,
 146,160,175,191,206,221, -1,241, -1,255,266,277,286,294,301,307,312,315,

/* v10 */
   2,  6, 11, 16, 19, 21, -1, -1, -1, -1, 54, 64, 75, 85, 95, -1, -1,131,
  -1,161,176,192,207,222, -1, -1, -1,256,267,278,287,295,302,308,313,316,

/* v11 */
  -1,  7, 12, 17, 20, 22, 25, -1, 37, -1, 55, 65, 76, 86, 96,105, -1, -1,
  -1,162,177,193,208,223, -1, -1, -1,257,268,279,288,296,303,309, -1, -1,

/* v12 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 66, 77, 87, -1, -1,118,132,
  -1,163,178, -1, -1, -1,232, -1, -1,258,269,280,289,297,304, -1, -1, -1,

/* v13 */
  -1, -1, -1, -1, -1, 23, -1, -1, -1, -1, -1, -1, 78, 88, -1, -1, -1,133,
  -1, -1,179,194,209, -1, -1, -1, -1, -1,270,281,290,298, -1, -1, -1, -1,

/* v14 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 89, 97,106,119, -1,
 147, -1, -1, -1,210, -1, -1, -1, -1,259,271, -1, -1, -1, -1, -1, -1, -1,

/* v15 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,107, -1,134,
 148,164,180,195,211,224,233, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,

/* v16 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 98,108,120,135,
 149,165,181,196,212,225, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,

/* v17 */
  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 99,109,121,136,
 150,166,182,197, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1

};
 
typedef struct {

	float32	lat;
	float32	lon_left;
	float32	lon_right;

} _tile_edge;

typedef struct	_land_tile_tbl {

	int32		reg_id;
	int16		i_horiz, i_vert;
	_tile_edge	edg[5];

}	_LAND_TILE_TBL;

_LAND_TILE_TBL	land_tile_tbl[N_LAND_TILE] = {

13, 0,  8,   0.0042, -180.0000, -170.0000,   2.5042, -180.0000, -170.1573,   5.0042, -180.0000, -170.6476,   7.5042, -180.0000, -171.4686,   9.9958, -180.0000, -172.6213,
13, 0,  9,  -9.9958, -180.0000, -172.6213,  -7.5042, -180.0000, -171.4686,  -5.0042, -180.0000, -170.6476,  -2.5042, -180.0000, -170.1573,  -0.0042, -180.0000, -170.0000,
13, 0, 10, -19.1792, -180.0000, -179.9912, -16.8792, -180.0000, -177.6487, -14.5875, -180.0000, -175.6601, -12.2958, -180.0000, -173.9871, -10.0042, -180.0000, -172.6211,
13, 1,  7,  10.0042, -172.6211, -162.4667,  12.5042, -174.1273, -163.8843,  15.0042, -175.9968, -165.6438,  17.5042, -178.2524, -167.7670,  19.9958, -180.0000, -170.2631,
13, 1,  8,   0.0042, -170.0000, -160.0000,   2.5042, -170.1573, -160.1478,   5.0042, -170.6476, -160.6093,   7.5042, -171.4686, -161.3822,   9.9958, -172.6213, -162.4671,
13, 1,  9,  -9.9958, -172.6213, -162.4671,  -7.5042, -171.4686, -161.3822,  -5.0042, -170.6476, -160.6093,  -2.5042, -170.1573, -160.1478,  -0.0042, -170.0000, -160.0000,
13, 1, 10, -19.9958, -180.0000, -170.2631, -17.5042, -178.2524, -167.7670, -15.0042, -175.9968, -165.6438, -12.5042, -174.1273, -163.8843, -10.0042, -172.6211, -162.4667,
13, 1, 11, -27.2625, -180.0000, -179.9906, -25.4542, -180.0000, -177.1943, -23.6375, -180.0000, -174.6513, -21.8208, -180.0000, -172.3431, -20.0042, -180.0000, -170.2715,
13, 2,  6,  20.0042, -170.2715, -159.6295,  22.5042, -173.1897, -162.3653,  25.0042, -176.5426, -165.5084,  27.5042, -180.0000, -169.1108,  29.9958, -180.0000, -173.1972,
13, 2,  8,   0.0042, -160.0000, -150.0000,   2.5042, -160.1478, -150.1383,   5.0042, -160.6093, -150.5709,   7.5042, -161.3822, -151.2958,   9.9958, -162.4671, -152.3129,
13, 2,  9,  -9.9958, -162.4671, -152.3129,  -7.5042, -161.3822, -151.2958,  -5.0042, -160.6093, -150.5709,  -2.5042, -160.1478, -150.1383,  -0.0042, -160.0000, -150.0000,
13, 2, 10, -19.9958, -170.2631, -159.6216, -17.5042, -167.7670, -157.2816, -15.0042, -165.6438, -155.2908, -12.5042, -163.8843, -153.6413, -10.0042, -162.4667, -152.3122,
13, 2, 11, -29.9958, -180.0000, -173.1972, -27.5042, -180.0000, -169.1108, -25.0042, -176.5426, -165.5084, -22.5042, -173.1897, -162.3653, -20.0042, -170.2715, -159.6295,
13, 3,  6,  20.0042, -159.6295, -148.9875,  22.5042, -162.3653, -151.5410,  25.0042, -165.5084, -154.4742,  27.5042, -169.1108, -157.8365,  29.9958, -173.1972, -161.6507,
13, 3,  7,  10.0042, -152.3122, -142.1578,  12.5042, -153.6413, -143.3982,  15.0042, -155.2908, -144.9378,  17.5042, -157.2816, -146.7961,  19.9958, -159.6216, -148.9802,
13, 3,  9,  -9.9958, -152.3129, -142.1587,  -7.5042, -151.2958, -141.2094,  -5.0042, -150.5709, -140.5326,  -2.5042, -150.1383, -140.1288,  -0.0042, -150.0000, -140.0000,
13, 3, 10, -19.9958, -159.6216, -148.9802, -17.5042, -157.2816, -146.7961, -15.0042, -155.2908, -144.9378, -12.5042, -153.6413, -143.3982, -10.0042, -152.3122, -142.1578,
13, 3, 11, -29.9958, -173.1972, -161.6507, -27.5042, -169.1108, -157.8365, -25.0042, -165.5084, -154.4742, -22.5042, -162.3653, -151.5410, -20.0042, -159.6295, -148.9875,
13, 4,  9,  -9.9958, -142.1587, -132.0045,  -7.5042, -141.2094, -131.1230,  -5.0042, -140.5326, -130.4942,  -2.5042, -140.1288, -130.1193,  -0.0042, -140.0000, -130.0000,
13, 4, 10, -19.9958, -148.9802, -138.3388, -17.5042, -146.7961, -136.3107, -15.0042, -144.9378, -134.5848, -12.5042, -143.3982, -133.1552, -10.0042, -142.1578, -132.0034,
13, 4, 11, -29.9958, -161.6507, -150.1042, -27.5042, -157.8365, -146.5621, -25.0042, -154.4742, -143.4400, -22.5042, -151.5410, -140.7166, -20.0042, -148.9875, -138.3456,
13, 5, 10, -19.9958, -138.3388, -127.6973, -17.5042, -136.3107, -125.8252, -15.0042, -134.5848, -124.2318, -12.5042, -133.1552, -122.9122, -10.0042, -132.0034, -121.8490,
13, 5, 11, -29.9958, -150.1042, -138.5578, -27.5042, -146.5621, -135.2877, -25.0042, -143.4400, -132.4058, -22.5042, -140.7166, -129.8923, -20.0042, -138.3456, -127.7036,
13, 5, 13, -48.1875, -180.0000, -179.9875, -46.1292, -180.0000, -173.1461, -44.0875, -180.0000, -167.0641, -42.0458, -175.0513, -161.5854, -40.0042, -169.7084, -156.6535,
13, 6,  3,  50.0042, -180.0000, -171.1446,  50.5875, -180.0000, -173.2536,  51.1708, -180.0000, -175.4412,  51.7542, -180.0000, -177.6980,  52.3292, -180.0000, -179.9864,
13, 6, 11, -29.9958, -138.5578, -127.0113, -27.5042, -135.2877, -124.0134, -25.0042, -132.4058, -121.3716, -22.5042, -129.8923, -119.0679, -20.0042, -127.7036, -117.0616,
13, 7,  3,  50.0042, -171.1446, -155.5860,  51.5625, -176.9437, -160.8579,  53.1208, -180.0000, -166.6281,  54.6792, -180.0000, -172.9660,  56.2458, -180.0000, -179.9700,
 2, 7,  5,  30.0042, -127.0167, -115.4692,  32.5042, -130.4263, -118.5689,  35.0042, -134.2904, -122.0822,  37.5042, -138.6543, -126.0488,  39.9958, -143.5812, -130.5279,
 2, 7,  6,  20.0042, -117.0616, -106.4197,  22.5042, -119.0679, -108.2435,  25.0042, -121.3716, -110.3374,  27.5042, -124.0134, -112.7390,  29.9958, -127.0113, -115.4648,
13, 7,  7,  10.0042, -111.6945, -101.5401,  12.5042, -112.6691, -102.4261,  15.0042, -113.8788, -103.5258,  17.5042, -115.3398, -104.8544,  19.9958, -117.0559, -106.4144,
13, 8,  3,  50.0042, -155.5860, -140.0274,  52.5042, -164.2835, -147.8552,  55.0042, -174.3623, -156.9261,  57.5042, -180.0000, -167.5135,  59.9958, -180.0000, -179.9667,
 2, 8,  4,  40.0042, -130.5437, -117.4887,  42.5042, -135.6443, -122.0799,  45.0042, -141.4248, -127.2817,  47.5042, -148.0252, -133.2221,  49.9958, -155.5515, -139.9957,
 1, 8,  5,  30.0042, -115.4692, -103.9218,  32.5042, -118.5689, -106.7115,  35.0042, -122.0822, -109.8740,  37.5042, -126.0488, -113.4434,  39.9958, -130.5279, -117.4745,
 2, 8,  6,  20.0042, -106.4197,  -95.7777,  22.5042, -108.2435,  -97.4192,  25.0042, -110.3374,  -99.3032,  27.5042, -112.7390, -101.4646,  29.9958, -115.4648, -103.9183,
 2, 8,  7,  10.0042, -101.5401,  -91.3857,  12.5042, -102.4261,  -92.1830,  15.0042, -103.5258,  -93.1728,  17.5042, -104.8544,  -94.3689,  19.9958, -106.4144,  -95.7730,
13, 8,  8,   0.0042, -100.0000,  -90.0000,   2.5042, -100.0908,  -90.0813,   5.0042, -100.3792,  -90.3409,   7.5042, -100.8639,  -90.7775,   9.9958, -101.5419,  -91.3877,
13, 8,  9,  -9.9958, -101.5419,  -91.3877,  -7.5042, -100.8639,  -90.7775,  -5.0042, -100.3792,  -90.3409,  -2.5042, -100.0908,  -90.0813,  -0.0042, -100.0000,  -90.0000,
13, 8, 11, -29.9958, -115.4648, -103.9183, -27.5042, -112.7390, -101.4646, -25.0042, -110.3374,  -99.3032, -22.5042, -108.2435,  -97.4192, -20.0042, -106.4197,  -95.7777,
10, 9,  2,  60.0042, -180.0000, -160.0139,  60.9042, -180.0000, -164.5080,  61.8042, -180.0000, -169.3116,  62.7042, -180.0000, -174.4395,  63.6042, -180.0000, -179.9438,
 2, 9,  3,  50.0042, -140.0274, -124.4688,  52.5042, -147.8552, -131.4268,  55.0042, -156.9261, -139.4898,  57.5042, -167.5135, -148.9000,  59.9958, -179.9667, -159.9694,
 2, 9,  4,  40.0042, -117.4887, -104.4338,  42.5042, -122.0799, -108.5154,  45.0042, -127.2817, -113.1386,  47.5042, -133.2221, -118.4189,  49.9958, -139.9957, -124.4399,
 1, 9,  5,  30.0042, -103.9218,  -92.3744,  32.5042, -106.7115,  -94.8541,  35.0042, -109.8740,  -97.6657,  37.5042, -113.4434, -100.8380,  39.9958, -117.4745, -104.4212,
 2, 9,  6,  20.0042,  -95.7777,  -85.1357,  22.5042,  -97.4192,  -86.5948,  25.0042,  -99.3032,  -88.2690,  27.5042, -101.4646,  -90.1903,  29.9958, -103.9183,  -92.3718,
 2, 9,  7,  10.0042,  -91.3857,  -81.2312,  12.5042,  -92.1830,  -81.9400,  15.0042,  -93.1728,  -82.8198,  17.5042,  -94.3689,  -83.8835,  19.9958,  -95.7730,  -85.1315,
 2, 9,  8,   0.0042,  -90.0000,  -80.0000,   2.5042,  -90.0813,  -80.0718,   5.0042,  -90.3409,  -80.3025,   7.5042,  -90.7775,  -80.6911,   9.9958,  -91.3877,  -81.2335,
 3, 9,  9,  -9.9958,  -91.3877,  -81.2335,  -7.5042,  -90.7775,  -80.6911,  -5.0042,  -90.3409,  -80.3025,  -2.5042,  -90.0813,  -80.0718,  -0.0042,  -90.0000,  -80.0000,
10,10,  2,  60.0042, -160.0139, -140.0111,  61.7792, -169.1796, -148.0321,  63.5542, -179.6258, -157.1714,  65.3292, -180.0000, -167.7019,  67.1125, -180.0000, -179.9786,
 2,10,  3,  50.0042, -124.4688, -108.9102,  52.5042, -131.4268, -114.9985,  55.0042, -139.4898, -122.0536,  57.5042, -148.9000, -130.2865,  59.9958, -159.9694, -139.9722,
 2,10,  4,  40.0042, -104.4338,  -91.3789,  42.5042, -108.5154,  -94.9510,  45.0042, -113.1386,  -98.9956,  47.5042, -118.4189, -103.6158,  49.9958, -124.4399, -108.8841,
 1,10,  5,  30.0042,  -92.3744,  -80.8270,  32.5042,  -94.8541,  -82.9967,  35.0042,  -97.6657,  -85.4575,  37.5042, -100.8380,  -88.2326,  39.9958, -104.4212,  -91.3679,
 2,10,  6,  20.0042,  -85.1357,  -74.4938,  22.5042,  -86.5948,  -75.7705,  25.0042,  -88.2690,  -77.2348,  27.5042,  -90.1903,  -78.9159,  29.9958,  -92.3718,  -80.8254,
 2,10,  7,  10.0042,  -81.2312,  -71.0768,  12.5042,  -81.9400,  -71.6970,  15.0042,  -82.8198,  -72.4667,  17.5042,  -83.8835,  -73.3981,  19.9958,  -85.1315,  -74.4901,
 3,10,  8,   0.0042,  -80.0000,  -70.0000,   2.5042,  -80.0718,  -70.0623,   5.0042,  -80.3025,  -70.2642,   7.5042,  -80.6911,  -70.6047,   9.9958,  -81.2335,  -71.0794,
 3,10,  9,  -9.9958,  -81.2335,  -71.0794,  -7.5042,  -80.6911,  -70.6047,  -5.0042,  -80.3025,  -70.2642,  -2.5042,  -80.0718,  -70.0623,  -0.0042,  -80.0000,  -70.0000,
 3,10, 10, -19.9958,  -85.1315,  -74.4901, -17.5042,  -83.8835,  -73.3981, -15.0042,  -82.8198,  -72.4667, -12.5042,  -81.9400,  -71.6970, -10.0042,  -81.2312,  -71.0768,
13,10, 11, -29.9958,  -92.3718,  -80.8254, -27.5042,  -90.1903,  -78.9159, -25.0042,  -88.2690,  -77.2348, -22.5042,  -86.5948,  -75.7705, -20.0042,  -85.1357,  -74.4938,
10,11,  2,  60.0042, -140.0111, -120.0083,  62.5042, -151.6079, -129.9484,  65.0042, -165.6623, -141.9963,  67.5042, -180.0000, -156.8044,  69.9958, -180.0000, -175.3959,
 2,11,  3,  50.0042, -108.9102,  -93.3516,  52.5042, -114.9985,  -98.5701,  55.0042, -122.0536, -104.6174,  57.5042, -130.2865, -111.6731,  59.9958, -139.9722, -119.9750,
 1,11,  4,  40.0042,  -91.3789,  -78.3240,  42.5042,  -94.9510,  -81.3866,  45.0042,  -98.9956,  -84.8525,  47.5042, -103.6158,  -88.8127,  49.9958, -108.8841,  -93.3283,
 1,11,  5,  30.0042,  -80.8270,  -69.2796,  32.5042,  -82.9967,  -71.1394,  35.0042,  -85.4575,  -73.2493,  37.5042,  -88.2326,  -75.6272,  39.9958,  -91.3679,  -78.3145,
 2,11,  6,  20.0042,  -74.4938,  -63.8518,  22.5042,  -75.7705,  -64.9461,  25.0042,  -77.2348,  -66.2006,  27.5042,  -78.9159,  -67.6415,  29.9958,  -80.8254,  -69.2789,
 3,11,  7,  10.0042,  -71.0768,  -60.9224,  12.5042,  -71.6970,  -61.4539,  15.0042,  -72.4667,  -62.1137,  17.5042,  -73.3981,  -62.9126,  19.9958,  -74.4901,  -63.8487,
 3,11,  8,   0.0042,  -70.0000,  -60.0000,   2.5042,  -70.0623,  -60.0528,   5.0042,  -70.2642,  -60.2259,   7.5042,  -70.6047,  -60.5183,   9.9958,  -71.0794,  -60.9252,
 3,11,  9,  -9.9958,  -71.0794,  -60.9252,  -7.5042,  -70.6047,  -60.5183,  -5.0042,  -70.2642,  -60.2259,  -2.5042,  -70.0623,  -60.0528,  -0.0042,  -70.0000,  -60.0000,
 1,11, 10, -19.9958,  -74.4901,  -63.8487, -17.5042,  -73.3981,  -62.9126, -15.0042,  -72.4667,  -62.1137, -12.5042,  -71.6970,  -61.4539, -10.0042,  -71.0768,  -60.9224,
 3,11, 11, -29.9958,  -80.8254,  -69.2789, -27.5042,  -78.9159,  -67.6415, -25.0042,  -77.2348,  -66.2006, -22.5042,  -75.7705,  -64.9461, -20.0042,  -74.4938,  -63.8518,
 3,11, 12, -39.9958,  -91.3679,  -78.3145, -37.5042,  -88.2326,  -75.6272, -35.0042,  -85.4575,  -73.2493, -32.5042,  -82.9967,  -71.1394, -30.0042,  -80.8270,  -69.2796,
10,12,  1,  70.0042, -175.4671, -146.2226,  70.9708, -180.0000, -153.3419,  71.9375, -180.0000, -161.2662,  72.9042, -180.0000, -170.0787,  73.8708, -180.0000, -179.9700,
10,12,  2,  60.0042, -120.0083, -100.0056,  62.5042, -129.9484, -108.2888,  65.0042, -141.9963, -118.3302,  67.5042, -156.8044, -130.6685,  69.9958, -175.3959, -146.1632,
 2,12,  3,  50.0042,  -93.3516,  -77.7930,  52.5042,  -98.5701,  -82.1418,  55.0042, -104.6174,  -87.1811,  57.5042, -111.6731,  -93.0596,  59.9958, -119.9750,  -99.9778,
 1,12,  4,  40.0042,  -78.3240,  -65.2691,  42.5042,  -81.3866,  -67.8222,  45.0042,  -84.8525,  -70.7094,  47.5042,  -88.8127,  -74.0095,  49.9958,  -93.3283,  -77.7725,
 2,12,  5,  30.0042,  -69.2796,  -57.7322,  32.5042,  -71.1394,  -59.2820,  35.0042,  -73.2493,  -61.0411,  37.5042,  -75.6272,  -63.0218,  39.9958,  -78.3145,  -65.2612,
13,12,  7,  10.0042,  -60.9224,  -50.7679,  12.5042,  -61.4539,  -51.2109,  15.0042,  -62.1137,  -51.7607,  17.5042,  -62.9126,  -52.4272,  19.9958,  -63.8487,  -53.2072,
 3,12,  8,   0.0042,  -60.0000,  -50.0000,   2.5042,  -60.0528,  -50.0433,   5.0042,  -60.2259,  -50.1875,   7.5042,  -60.5183,  -50.4319,   9.9958,  -60.9252,  -50.7710,
 3,12,  9,  -9.9958,  -60.9252,  -50.7710,  -7.5042,  -60.5183,  -50.4319,  -5.0042,  -60.2259,  -50.1875,  -2.5042,  -60.0528,  -50.0433,  -0.0042,  -60.0000,  -50.0000,
 3,12, 10, -19.9958,  -63.8487,  -53.2072, -17.5042,  -62.9126,  -52.4272, -15.0042,  -62.1137,  -51.7607, -12.5042,  -61.4539,  -51.2109, -10.0042,  -60.9224,  -50.7679,
 3,12, 11, -29.9958,  -69.2789,  -57.7324, -27.5042,  -67.6415,  -56.3671, -25.0042,  -66.2006,  -55.1664, -22.5042,  -64.9461,  -54.1218, -20.0042,  -63.8518,  -53.2098,
 3,12, 12, -39.9958,  -78.3145,  -65.2612, -37.5042,  -75.6272,  -63.0218, -35.0042,  -73.2493,  -61.0411, -32.5042,  -71.1394,  -59.2820, -30.0042,  -69.2796,  -57.7322,
 3,12, 13, -49.9958,  -93.3283,  -77.7725, -47.5042,  -88.8127,  -74.0095, -45.0042,  -84.8525,  -70.7094, -42.5042,  -81.3866,  -67.8222, -40.0042,  -78.3240,  -65.2691,
10,13,  1,  70.0042, -146.2226, -116.9781,  71.7875, -159.9763, -127.9810,  73.5708, -176.7883, -141.4307,  75.3542, -180.0000, -158.1818,  77.1542, -180.0000, -179.8876,
10,13,  2,  60.0042, -100.0056,  -80.0028,  62.5042, -108.2888,  -86.6292,  65.0042, -118.3302,  -94.6642,  67.5042, -130.6685, -104.5326,  69.9958, -146.1632, -116.9306,
 2,13,  3,  50.0042,  -77.7930,  -62.2344,  52.5042,  -82.1418,  -65.7134,  55.0042,  -87.1811,  -69.7449,  57.5042,  -93.0596,  -74.4461,  59.9958,  -99.9778,  -79.9806,
 2,13,  4,  40.0042,  -65.2691,  -52.2142,  42.5042,  -67.8222,  -54.2577,  45.0042,  -70.7094,  -56.5664,  47.5042,  -74.0095,  -59.2064,  49.9958,  -77.7725,  -62.2167,
 3,13,  8,   0.0042,  -50.0000,  -40.0000,   2.5042,  -50.0433,  -40.0338,   5.0042,  -50.1875,  -40.1492,   7.5042,  -50.4319,  -40.3456,   9.9958,  -50.7710,  -40.6168,
 3,13,  9,  -9.9958,  -50.7710,  -40.6168,  -7.5042,  -50.4319,  -40.3456,  -5.0042,  -50.1875,  -40.1492,  -2.5042,  -50.0433,  -40.0338,  -0.0042,  -50.0000,  -40.0000,
 3,13, 10, -19.9958,  -53.2072,  -42.5658, -17.5042,  -52.4272,  -41.9417, -15.0042,  -51.7607,  -41.4077, -12.5042,  -51.2109,  -40.9679, -10.0042,  -50.7679,  -40.6135,
 3,13, 11, -29.9958,  -57.7324,  -46.1859, -27.5042,  -56.3671,  -45.0928, -25.0042,  -55.1664,  -44.1322, -22.5042,  -54.1218,  -43.2974, -20.0042,  -53.2098,  -42.5679,
 3,13, 12, -39.9958,  -65.2612,  -52.2079, -37.5042,  -63.0218,  -50.4164, -35.0042,  -61.0411,  -48.8329, -32.5042,  -59.2820,  -47.4246, -30.0042,  -57.7322,  -46.1848,
 3,13, 13, -49.9958,  -77.7725,  -62.2167, -47.5042,  -74.0095,  -59.2064, -45.0042,  -70.7094,  -56.5664, -42.5042,  -67.8222,  -54.2577, -40.0042,  -65.2691,  -52.2142,
 3,13, 14, -59.9958,  -99.9778,  -79.9806, -57.5042,  -93.0596,  -74.4461, -55.0042,  -87.1811,  -69.7449, -52.5042,  -82.1418,  -65.7134, -50.0042,  -77.7930,  -62.2344,
10,14,  1,  70.0042, -116.9781,  -87.7335,  72.5042, -133.0423,  -99.7782,  75.0042, -154.5894, -115.9420,  77.5042, -180.0000, -138.6349,  79.9958, -180.0000, -172.6609,
10,14,  2,  60.0042,  -80.0028,  -60.0000,  62.5042,  -86.6292,  -64.9697,  65.0042,  -94.6642,  -70.9981,  67.5042, -104.5326,  -78.3968,  69.9958, -116.9306,  -87.6979,
 2,14,  3,  50.0042,  -62.2344,  -46.6758,  52.5042,  -65.7134,  -49.2851,  55.0042,  -69.7449,  -52.3087,  57.5042,  -74.4461,  -55.8327,  59.9958,  -79.9806,  -59.9833,
 2,14,  4,  40.0042,  -52.2142,  -39.1593,  42.5042,  -54.2577,  -40.6933,  45.0042,  -56.5664,  -42.4233,  47.5042,  -59.2064,  -44.4032,  49.9958,  -62.2167,  -46.6609,
 3,14,  9,  -9.9958,  -40.6168,  -30.4626,  -7.5042,  -40.3456,  -30.2592,  -5.0042,  -40.1492,  -30.1108,  -2.5042,  -40.0338,  -30.0243,  -0.0042,  -40.0000,  -30.0000,
 3,14, 10, -19.9958,  -42.5658,  -31.9243, -17.5042,  -41.9417,  -31.4563, -15.0042,  -41.4077,  -31.0547, -12.5042,  -40.9679,  -30.7248, -10.0042,  -40.6135,  -30.4591,
 3,14, 11, -29.9958,  -46.1859,  -34.6394, -27.5042,  -45.0928,  -33.8184, -25.0042,  -44.1322,  -33.0980, -22.5042,  -43.2974,  -32.4731, -20.0042,  -42.5679,  -31.9259,
 3,14, 14, -59.9958,  -79.9806,  -59.9833, -57.5042,  -74.4461,  -55.8327, -55.0042,  -69.7449,  -52.3087, -52.5042,  -65.7134,  -49.2851, -50.0042,  -62.2344,  -46.6758,
12,14, 16, -79.9958, -180.0000, -172.6609, -77.5042, -180.0000, -138.6349, -75.0042, -154.5894, -115.9420, -72.5042, -133.0423,  -99.7782, -70.0042, -116.9781,  -87.7335,
12,14, 17, -80.4042, -180.0000, -179.9500, -80.3042, -180.0000, -178.1198, -80.2042, -180.0000, -176.3265, -80.1042, -180.0000, -174.5690, -80.0042, -180.0000, -172.7990,
10,15,  1,  70.0042,  -87.7335,  -58.4890,  72.5042,  -99.7782,  -66.5142,  75.0042, -115.9420,  -77.2947,  77.5042, -138.6349,  -92.4168,  79.9958, -172.6609, -115.0993,
10,15,  2,  60.0042,  -60.0000,  -39.9972,  62.5042,  -64.9697,  -43.3101,  65.0042,  -70.9981,  -47.3321,  67.5042,  -78.3968,  -52.2609,  69.9958,  -87.6979,  -58.4653,
13,15,  3,  50.0042,  -46.6758,  -31.1172,  52.5042,  -49.2851,  -32.8567,  55.0042,  -52.3087,  -34.8725,  57.5042,  -55.8327,  -37.2192,  59.9958,  -59.9833,  -39.9861,
13,15,  5,  30.0042,  -34.6374,  -23.0900,  32.5042,  -35.5672,  -23.7098,  35.0042,  -36.6247,  -24.4164,  37.5042,  -37.8110,  -25.2056,  39.9958,  -39.1546,  -26.1012,
13,15,  7,  10.0042,  -30.4591,  -20.3046,  12.5042,  -30.7248,  -20.4818,  15.0042,  -31.0547,  -20.7017,  17.5042,  -31.4563,  -20.9709,  19.9958,  -31.9243,  -21.2829,
13,15, 11, -29.9958,  -34.6394,  -23.0930, -27.5042,  -33.8184,  -22.5440, -25.0042,  -33.0980,  -22.0638, -22.5042,  -32.4731,  -21.6487, -20.0042,  -31.9259,  -21.2839,
13,15, 14, -59.9958,  -59.9833,  -39.9861, -57.5042,  -55.8327,  -37.2192, -55.0042,  -52.3087,  -34.8725, -52.5042,  -49.2851,  -32.8567, -50.0042,  -46.6758,  -31.1172,
 1,15, 15, -69.9958,  -87.6979,  -58.4653, -67.5042,  -78.3968,  -52.2609, -65.0042,  -70.9981,  -47.3321, -62.5042,  -64.9697,  -43.3101, -60.0042,  -60.0000,  -39.9972,
12,15, 16, -79.9958, -172.6609, -115.0993, -77.5042, -138.6349,  -92.4168, -75.0042, -115.9420,  -77.2947, -72.5042,  -99.7782,  -66.5142, -70.0042,  -87.7335,  -58.4890,
12,15, 17, -83.6125, -180.0000, -179.7753, -82.7042, -180.0000, -157.4918, -81.8042, -180.0000, -140.3053, -80.9042, -180.0000, -126.4929, -80.0042, -172.7990, -115.1914,
10,16,  0,  80.0042, -115.1914,  -57.5837,  81.7042, -138.5882,  -69.2796,  83.4042, -174.1233,  -87.0617,  85.1042, -180.0000, -117.1196,  86.8125, -180.0000, -179.8501,
10,16,  1,  70.0042,  -58.4890,  -29.2445,  72.5042,  -66.5142,  -33.2502,  75.0042,  -77.2947,  -38.6473,  77.5042,  -92.4168,  -46.1988,  79.9958, -115.0993,  -57.5376,
10,16,  2,  60.0042,  -39.9972,  -19.9944,  62.5042,  -43.3101,  -21.6505,  65.0042,  -47.3321,  -23.6660,  67.5042,  -52.2609,  -26.1250,  69.9958,  -58.4653,  -29.2326,
13,16,  5,  30.0042,  -23.0900,  -11.5426,  32.5042,  -23.7098,  -11.8524,  35.0042,  -24.4164,  -12.2082,  37.5042,  -25.2056,  -12.6002,  39.9958,  -26.1012,  -13.0479,
 4,16,  6,  20.0042,  -21.2839,  -10.6420,  22.5042,  -21.6487,  -10.8244,  25.0042,  -22.0638,  -11.0296,  27.5042,  -22.5440,  -11.2697,  29.9958,  -23.0930,  -11.5465,
 4,16,  7,  10.0042,  -20.3046,  -10.1502,  12.5042,  -20.4818,  -10.2388,  15.0042,  -20.7017,  -10.3487,  17.5042,  -20.9709,  -10.4854,  19.9958,  -21.2829,  -10.6414,
 4,16,  8,   0.0042,  -20.0000,  -10.0000,   2.5042,  -20.0148,  -10.0053,   5.0042,  -20.0725,  -10.0342,   7.5042,  -20.1728,  -10.0864,   9.9958,  -20.3084,  -10.1542,
13,16,  9,  -9.9958,  -20.3084,  -10.1542,  -7.5042,  -20.1728,  -10.0864,  -5.0042,  -20.0725,  -10.0342,  -2.5042,  -20.0148,  -10.0053,  -0.0042,  -20.0000,  -10.0000,
13,16, 12, -39.9958,  -26.1012,  -13.0479, -37.5042,  -25.2056,  -12.6002, -35.0042,  -24.4164,  -12.2082, -32.5042,  -23.7098,  -11.8524, -30.0042,  -23.0900,  -11.5426,
13,16, 14, -59.9958,  -39.9861,  -19.9889, -57.5042,  -37.2192,  -18.6057, -55.0042,  -34.8725,  -17.4362, -52.5042,  -32.8567,  -16.4284, -50.0042,  -31.1172,  -15.5586,
12,16, 16, -79.9958, -115.0993,  -57.5376, -77.5042,  -92.4168,  -46.1988, -75.0042,  -77.2947,  -38.6473, -72.5042,  -66.5142,  -33.2502, -70.0042,  -58.4890,  -29.2445,
12,16, 17, -86.8125, -180.0000, -179.8501, -85.1042, -180.0000, -117.1196, -83.4042, -174.1233,  -87.0617, -81.7042, -138.5882,  -69.2796, -80.0042, -115.1914,  -57.5837,
10,17,  0,  80.0042,  -57.5837,    0.0240,  82.5042,  -76.6501,    0.0000,  85.0042, -114.8325,   -0.0000,  87.5042, -180.0000,    0.0957,  89.9958, -180.0000,   60.0000,
10,17,  1,  70.0042,  -29.2445,   -0.0000,  72.5042,  -33.2502,    0.0139,  75.0042,  -38.6473,    0.0000,  77.5042,  -46.1988,    0.0193,  79.9958,  -57.5376,    0.0240,
10,17,  2,  60.0042,  -19.9944,    0.0083,  62.5042,  -21.6505,    0.0090,  65.0042,  -23.6660,   -0.0000,  67.5042,  -26.1250,    0.0109,  69.9958,  -29.2326,   -0.0000,
 5,17,  3,  50.0042,  -15.5586,   -0.0000,  52.5042,  -16.4284,   -0.0000,  55.0042,  -17.4362,    0.0000,  57.5042,  -18.6057,    0.0078,  59.9958,  -19.9889,    0.0083,
 5,17,  4,  40.0042,  -13.0495,    0.0054,  42.5042,  -13.5644,    0.0000,  45.0042,  -14.1372,    0.0059,  47.5042,  -14.7970,    0.0062,  49.9958,  -15.5493,    0.0065,
 4,17,  5,  30.0042,  -11.5426,    0.0048,  32.5042,  -11.8524,    0.0049,  35.0042,  -12.2082,   -0.0000,  37.5042,  -12.6002,    0.0053,  39.9958,  -13.0479,    0.0054,
 4,17,  6,  20.0042,  -10.6420,    0.0000,  22.5042,  -10.8244,   -0.0000,  25.0042,  -11.0296,    0.0046,  27.5042,  -11.2697,    0.0047,  29.9958,  -11.5465,   -0.0000,
 4,17,  7,  10.0042,  -10.1502,    0.0042,  12.5042,  -10.2388,    0.0043,  15.0042,  -10.3487,    0.0043,  17.5042,  -10.4854,    0.0000,  19.9958,  -10.6414,   -0.0000,
 4,17,  8,   0.0042,  -10.0000,    0.0000,   2.5042,  -10.0053,    0.0042,   5.0042,  -10.0342,    0.0042,   7.5042,  -10.0864,   -0.0000,   9.9958,  -10.1542,   -0.0000,
13,17, 10, -19.9958,  -10.6414,   -0.0000, -17.5042,  -10.4854,    0.0000, -15.0042,  -10.3487,    0.0043, -12.5042,  -10.2388,    0.0043, -10.0042,  -10.1502,    0.0042,
13,17, 12, -39.9958,  -13.0479,    0.0054, -37.5042,  -12.6002,    0.0053, -35.0042,  -12.2082,   -0.0000, -32.5042,  -11.8524,    0.0049, -30.0042,  -11.5426,    0.0048,
13,17, 13, -49.9958,  -15.5493,    0.0065, -47.5042,  -14.7970,    0.0062, -45.0042,  -14.1372,    0.0059, -42.5042,  -13.5644,    0.0000, -40.0042,  -13.0495,    0.0054,
12,17, 15, -69.9958,  -29.2326,   -0.0000, -67.5042,  -26.1250,    0.0109, -65.0042,  -23.6660,   -0.0000, -62.5042,  -21.6505,    0.0090, -60.0042,  -19.9944,    0.0083,
12,17, 16, -79.9958,  -57.5376,    0.0240, -77.5042,  -46.1988,    0.0193, -75.0042,  -38.6473,    0.0000, -72.5042,  -33.2502,    0.0139, -70.0042,  -29.2445,   -0.0000,
12,17, 17, -89.9958, -180.0000,   60.0000, -87.5042, -180.0000,    0.0957, -85.0042, -114.8325,   -0.0000, -82.5042,  -76.6501,    0.0000, -80.0042,  -57.5837,    0.0240,
11,18,  0,  80.0042,    0.0240,   57.6317,  82.5042,    0.0000,   76.6501,  85.0042,    0.0000,  114.8325,  87.5042,    0.0957,  180.0000,  89.9958,   60.0000,  180.0000,
11,18,  1,  70.0042,   -0.0000,   29.2445,  72.5042,    0.0139,   33.2779,  75.0042,    0.0000,   38.6473,  77.5042,    0.0193,   46.2373,  79.9958,    0.0240,   57.5856,
11,18,  2,  60.0042,    0.0083,   20.0111,  62.5042,    0.0090,   21.6686,  65.0042,   -0.0000,   23.6660,  67.5042,    0.0109,   26.1468,  69.9958,    0.0000,   29.2326,
 5,18,  3,  50.0042,   -0.0000,   15.5586,  52.5042,   -0.0000,   16.4284,  55.0042,   -0.0000,   17.4362,  57.5042,    0.0078,   18.6212,  59.9958,    0.0083,   20.0056,
 1,18,  4,  40.0042,    0.0054,   13.0603,  42.5042,    0.0000,   13.5644,  45.0042,    0.0059,   14.1490,  47.5042,    0.0062,   14.8093,  49.9958,    0.0065,   15.5623,
 4,18,  5,  30.0042,    0.0048,   11.5522,  32.5042,    0.0049,   11.8623,  35.0042,    0.0000,   12.2082,  37.5042,    0.0053,   12.6107,  39.9958,    0.0054,   13.0588,
 1,18,  6,  20.0042,   -0.0000,   10.6420,  22.5042,   -0.0000,   10.8244,  25.0042,    0.0046,   11.0388,  27.5042,    0.0047,   11.2791,  29.9958,   -0.0000,   11.5465,
 1,18,  7,  10.0042,    0.0042,   10.1587,  12.5042,    0.0043,   10.2473,  15.0042,    0.0043,   10.3573,  17.5042,   -0.0000,   10.4854,  19.9958,    0.0000,   10.6414,
 4,18,  8,   0.0042,   -0.0000,   10.0000,   2.5042,    0.0042,   10.0137,   5.0042,    0.0042,   10.0425,   7.5042,    0.0000,   10.0864,   9.9958,    0.0000,   10.1542,
 4,18,  9,  -9.9958,    0.0000,   10.1542,  -7.5042,    0.0000,   10.0864,  -5.0042,    0.0042,   10.0425,  -2.5042,    0.0042,   10.0137,  -0.0042,   -0.0000,   10.0000,
13,18, 14, -59.9958,    0.0083,   20.0056, -57.5042,    0.0078,   18.6212, -55.0042,   -0.0000,   17.4362, -52.5042,   -0.0000,   16.4284, -50.0042,   -0.0000,   15.5586,
13,18, 15, -69.9958,    0.0000,   29.2326, -67.5042,    0.0109,   26.1468, -65.0042,   -0.0000,   23.6660, -62.5042,    0.0090,   21.6686, -60.0042,    0.0083,   20.0111,
12,18, 16, -79.9958,    0.0240,   57.5856, -77.5042,    0.0193,   46.2373, -75.0042,    0.0000,   38.6473, -72.5042,    0.0139,   33.2779, -70.0042,   -0.0000,   29.2445,
12,18, 17, -89.9958,   60.0000,  180.0000, -87.5042,    0.0957,  180.0000, -85.0042,    0.0000,  114.8325, -82.5042,    0.0000,   76.6501, -80.0042,    0.0240,   57.6317,
11,19,  0,  80.0042,   57.6317,  115.2394,  81.7042,   69.3374,  138.6459,  83.4042,   87.0617,  174.1233,  85.1042,  117.2172,  180.0000,  86.8125,  179.8501,  180.0000,
11,19,  1,  70.0042,   29.2445,   58.4890,  72.5042,   33.2779,   66.5419,  75.0042,   38.6473,   77.2947,  77.5042,   46.2373,   92.4553,  79.9958,   57.5856,  115.1472,
11,19,  2,  60.0042,   20.0111,   40.0139,  62.5042,   21.6686,   43.3282,  65.0042,   23.6660,   47.3321,  67.5042,   26.1468,   52.2827,  69.9958,   29.2326,   58.4653,
 5,19,  3,  50.0042,   15.5586,   31.1172,  52.5042,   16.4284,   32.8567,  55.0042,   17.4362,   34.8725,  57.5042,   18.6212,   37.2347,  59.9958,   20.0056,   40.0028,
 5,19,  4,  40.0042,   13.0603,   26.1153,  42.5042,   13.5644,   27.1289,  45.0042,   14.1490,   28.2920,  47.5042,   14.8093,   29.6124,  49.9958,   15.5623,   31.1181,
 5,19,  5,  30.0042,   11.5522,   23.0996,  32.5042,   11.8623,   23.7197,  35.0042,   12.2082,   24.4164,  37.5042,   12.6107,   25.2161,  39.9958,   13.0588,   26.1121,
 4,19,  6,  20.0042,   10.6420,   21.2839,  22.5042,   10.8244,   21.6487,  25.0042,   11.0388,   22.0730,  27.5042,   11.2791,   22.5534,  29.9958,   11.5465,   23.0930,
 4,19,  7,  10.0042,   10.1587,   20.3131,  12.5042,   10.2473,   20.4903,  15.0042,   10.3573,   20.7103,  17.5042,   10.4854,   20.9709,  19.9958,   10.6414,   21.2829,
 4,19,  8,   0.0042,   10.0000,   20.0000,   2.5042,   10.0137,   20.0232,   5.0042,   10.0425,   20.0809,   7.5042,   10.0864,   20.1728,   9.9958,   10.1542,   20.3084,
 4,19,  9,  -9.9958,   10.1542,   20.3084,  -7.5042,   10.0864,   20.1728,  -5.0042,   10.0425,   20.0809,  -2.5042,   10.0137,   20.0232,  -0.0042,   10.0000,   20.0000,
 4,19, 10, -19.9958,   10.6414,   21.2829, -17.5042,   10.4854,   20.9709, -15.0042,   10.3573,   20.7103, -12.5042,   10.2473,   20.4903, -10.0042,   10.1587,   20.3131,
 4,19, 11, -29.9958,   11.5465,   23.0930, -27.5042,   11.2791,   22.5534, -25.0042,   11.0388,   22.0730, -22.5042,   10.8244,   21.6487, -20.0042,   10.6420,   21.2839,
 4,19, 12, -39.9958,   13.0588,   26.1121, -37.5042,   12.6107,   25.2161, -35.0042,   12.2082,   24.4164, -32.5042,   11.8623,   23.7197, -30.0042,   11.5522,   23.0996,
12,19, 15, -69.9958,   29.2326,   58.4653, -67.5042,   26.1468,   52.2827, -65.0042,   23.6660,   47.3321, -62.5042,   21.6686,   43.3282, -60.0042,   20.0111,   40.0139,
12,19, 16, -79.9958,   57.5856,  115.1472, -77.5042,   46.2373,   92.4553, -75.0042,   38.6473,   77.2947, -72.5042,   33.2779,   66.5419, -70.0042,   29.2445,   58.4890,
12,19, 17, -86.8125,  179.8501,  180.0000, -85.1042,  117.2172,  180.0000, -83.4042,   87.0617,  174.1233, -81.7042,   69.3374,  138.6459, -80.0042,   57.6317,  115.2394,
11,20,  1,  70.0042,   58.4890,   87.7335,  72.5042,   66.5419,   99.8060,  75.0042,   77.2947,  115.9420,  77.5042,   92.4553,  138.6734,  79.9958,  115.1472,  172.7089,
11,20,  2,  60.0042,   40.0139,   60.0167,  62.5042,   43.3282,   64.9877,  65.0042,   47.3321,   70.9981,  67.5042,   52.2827,   78.4185,  69.9958,   58.4653,   87.6979,
 5,20,  3,  50.0042,   31.1172,   46.6758,  52.5042,   32.8567,   49.2851,  55.0042,   34.8725,   52.3087,  57.5042,   37.2347,   55.8482,  59.9958,   40.0028,   60.0000,
 5,20,  4,  40.0042,   26.1153,   39.1702,  42.5042,   27.1289,   40.6933,  45.0042,   28.2920,   42.4351,  47.5042,   29.6124,   44.4156,  49.9958,   31.1181,   46.6739,
 5,20,  5,  30.0042,   23.0996,   34.6470,  32.5042,   23.7197,   35.5771,  35.0042,   24.4164,   36.6247,  37.5042,   25.2161,   37.8215,  39.9958,   26.1121,   39.1654,
 4,20,  6,  20.0042,   21.2839,   31.9259,  22.5042,   21.6487,   32.4731,  25.0042,   22.0730,   33.1072,  27.5042,   22.5534,   33.8278,  29.9958,   23.0930,   34.6394,
 4,20,  7,  10.0042,   20.3131,   30.4675,  12.5042,   20.4903,   30.7334,  15.0042,   20.7103,   31.0633,  17.5042,   20.9709,   31.4563,  19.9958,   21.2829,   31.9243,
 4,20,  8,   0.0042,   20.0000,   30.0000,   2.5042,   20.0232,   30.0327,   5.0042,   20.0809,   30.1192,   7.5042,   20.1728,   30.2592,   9.9958,   20.3084,   30.4626,
 4,20,  9,  -9.9958,   20.3084,   30.4626,  -7.5042,   20.1728,   30.2592,  -5.0042,   20.0809,   30.1192,  -2.5042,   20.0232,   30.0327,  -0.0042,   20.0000,   30.0000,
 4,20, 10, -19.9958,   21.2829,   31.9243, -17.5042,   20.9709,   31.4563, -15.0042,   20.7103,   31.0633, -12.5042,   20.4903,   30.7334, -10.0042,   20.3131,   30.4675,
 4,20, 11, -29.9958,   23.0930,   34.6394, -27.5042,   22.5534,   33.8278, -25.0042,   22.0730,   33.1072, -22.5042,   21.6487,   32.4731, -20.0042,   21.2839,   31.9259,
 4,20, 12, -39.9958,   26.1121,   39.1654, -37.5042,   25.2161,   37.8215, -35.0042,   24.4164,   36.6247, -32.5042,   23.7197,   35.5771, -30.0042,   23.0996,   34.6470,
13,20, 13, -49.9958,   31.1181,   46.6739, -47.5042,   29.6124,   44.4156, -45.0042,   28.2920,   42.4351, -42.5042,   27.1289,   40.6933, -40.0042,   26.1153,   39.1702,
 1,20, 15, -69.9958,   58.4653,   87.6979, -67.5042,   52.2827,   78.4185, -65.0042,   47.3321,   70.9981, -62.5042,   43.3282,   64.9877, -60.0042,   40.0139,   60.0167,
12,20, 16, -79.9958,  115.1472,  172.7089, -77.5042,   92.4553,  138.6734, -75.0042,   77.2947,  115.9420, -72.5042,   66.5419,   99.8060, -70.0042,   58.4890,   87.7335,
12,20, 17, -83.6125,  179.7753,  180.0000, -82.7042,  157.4918,  180.0000, -81.8042,  140.3053,  180.0000, -80.9042,  126.5456,  180.0000, -80.0042,  115.2394,  172.8470,
11,21,  1,  70.0042,   87.7335,  116.9781,  72.5042,   99.8060,  133.0700,  75.0042,  115.9420,  154.5894,  77.5042,  138.6734,  180.0000,  79.9958,  172.7089,  180.0000,
11,21,  2,  60.0042,   60.0167,   80.0194,  62.5042,   64.9877,   86.6473,  65.0042,   70.9981,   94.6642,  67.5042,   78.4185,  104.5544,  69.9958,   87.6979,  116.9306,
 5,21,  3,  50.0042,   46.6758,   62.2344,  52.5042,   49.2851,   65.7134,  55.0042,   52.3087,   69.7449,  57.5042,   55.8482,   74.4616,  59.9958,   60.0000,   79.9972,
 5,21,  4,  40.0042,   39.1702,   52.2251,  42.5042,   40.6933,   54.2577,  45.0042,   42.4351,   56.5782,  47.5042,   44.4156,   59.2187,  49.9958,   46.6739,   62.2297,
 1,21,  5,  30.0042,   34.6470,   46.1944,  32.5042,   35.5771,   47.4345,  35.0042,   36.6247,   48.8329,  37.5042,   37.8215,   50.4269,  39.9958,   39.1654,   52.2188,
 6,21,  6,  20.0042,   31.9259,   42.5679,  22.5042,   32.4731,   43.2974,  25.0042,   33.1072,   44.1414,  27.5042,   33.8278,   45.1022,  29.9958,   34.6394,   46.1859,
 4,21,  7,  10.0042,   30.4675,   40.6220,  12.5042,   30.7334,   40.9764,  15.0042,   31.0633,   41.4163,  17.5042,   31.4563,   41.9417,  19.9958,   31.9243,   42.5658,
 4,21,  8,   0.0042,   30.0000,   40.0000,   2.5042,   30.0327,   40.0422,   5.0042,   30.1192,   40.1575,   7.5042,   30.2592,   40.3456,   9.9958,   30.4626,   40.6168,
 4,21,  9,  -9.9958,   30.4626,   40.6168,  -7.5042,   30.2592,   40.3456,  -5.0042,   30.1192,   40.1575,  -2.5042,   30.0327,   40.0422,  -0.0042,   30.0000,   40.0000,
 4,21, 10, -19.9958,   31.9243,   42.5658, -17.5042,   31.4563,   41.9417, -15.0042,   31.0633,   41.4163, -12.5042,   30.7334,   40.9764, -10.0042,   30.4675,   40.6220,
 4,21, 11, -29.9958,   34.6394,   46.1859, -27.5042,   33.8278,   45.1022, -25.0042,   33.1072,   44.1414, -22.5042,   32.4731,   43.2974, -20.0042,   31.9259,   42.5679,
13,21, 13, -49.9958,   46.6739,   62.2297, -47.5042,   44.4156,   59.2187, -45.0042,   42.4351,   56.5782, -42.5042,   40.6933,   54.2577, -40.0042,   39.1702,   52.2251,
12,21, 15, -69.9958,   87.6979,  116.9306, -67.5042,   78.4185,  104.5544, -65.0042,   70.9981,   94.6642, -62.5042,   64.9877,   86.6473, -60.0042,   60.0167,   80.0194,
12,21, 16, -79.9958,  172.7089,  180.0000, -77.5042,  138.6734,  180.0000, -75.0042,  115.9420,  154.5894, -72.5042,   99.8060,  133.0700, -70.0042,   87.7335,  116.9781,
12,21, 17, -80.3958,  179.8002,  180.0000, -80.3042,  178.1198,  180.0000, -80.2042,  176.3265,  180.0000, -80.1042,  174.5690,  180.0000, -80.0042,  172.8470,  180.0000,
11,22,  1,  70.0042,  116.9781,  146.2226,  71.7875,  127.9810,  159.9763,  73.5708,  141.4307,  176.7883,  75.3542,  158.2148,  180.0000,  77.1542,  179.9250,  180.0000,
11,22,  2,  60.0042,   80.0194,  100.0222,  62.5042,   86.6473,  108.3068,  65.0042,   94.6642,  118.3302,  67.5042,  104.5544,  130.6903,  69.9958,  116.9306,  146.1632,
 6,22,  3,  50.0042,   62.2344,   77.7930,  52.5042,   65.7134,   82.1418,  55.0042,   69.7449,   87.1811,  57.5042,   74.4616,   93.0751,  59.9958,   79.9972,   99.9944,
 6,22,  4,  40.0042,   52.2251,   65.2800,  42.5042,   54.2577,   67.8222,  45.0042,   56.5782,   70.7212,  47.5042,   59.2187,   74.0219,  49.9958,   62.2297,   77.7855,
 6,22,  5,  30.0042,   46.1944,   57.7418,  32.5042,   47.4345,   59.2919,  35.0042,   48.8329,   61.0411,  37.5042,   50.4269,   63.0323,  39.9958,   52.2188,   65.2721,
 6,22,  6,  20.0042,   42.5679,   53.2098,  22.5042,   43.2974,   54.1218,  25.0042,   44.1414,   55.1756,  27.5042,   45.1022,   56.3765,  29.9958,   46.1859,   57.7324,
 6,22,  7,  10.0042,   40.6220,   50.7764,  12.5042,   40.9764,   51.2194,  15.0042,   41.4163,   51.7694,  17.5042,   41.9417,   52.4272,  19.9958,   42.5658,   53.2072,
 4,22,  8,   0.0042,   40.0000,   50.0000,   2.5042,   40.0422,   50.0517,   5.0042,   40.1575,   50.1959,   7.5042,   40.3456,   50.4319,   9.9958,   40.6168,   50.7710,
 4,22,  9,  -9.9958,   40.6168,   50.7710,  -7.5042,   40.3456,   50.4319,  -5.0042,   40.1575,   50.1959,  -2.5042,   40.0422,   50.0517,  -0.0042,   40.0000,   50.0000,
 4,22, 10, -19.9958,   42.5658,   53.2072, -17.5042,   41.9417,   52.4272, -15.0042,   41.4163,   51.7694, -12.5042,   40.9764,   51.2194, -10.0042,   40.6220,   50.7764,
 4,22, 11, -29.9958,   46.1859,   57.7324, -27.5042,   45.1022,   56.3765, -25.0042,   44.1414,   55.1756, -22.5042,   43.2974,   54.1218, -20.0042,   42.5679,   53.2098,
13,22, 13, -49.9958,   62.2297,   77.7855, -47.5042,   59.2187,   74.0219, -45.0042,   56.5782,   70.7212, -42.5042,   54.2577,   67.8222, -40.0042,   52.2251,   65.2800,
13,22, 14, -59.9958,   79.9972,   99.9944, -57.5042,   74.4616,   93.0751, -55.0042,   69.7449,   87.1811, -52.5042,   65.7134,   82.1418, -50.0042,   62.2344,   77.7930,
12,22, 15, -69.9958,  116.9306,  146.1632, -67.5042,  104.5544,  130.6903, -65.0042,   94.6642,  118.3302, -62.5042,   86.6473,  108.3068, -60.0042,   80.0194,  100.0222,
 1,22, 16, -77.1542,  179.9250,  180.0000, -75.3542,  158.2148,  180.0000, -73.5708,  141.4307,  176.7883, -71.7875,  127.9810,  159.9763, -70.0042,  116.9781,  146.2226,
11,23,  1,  70.0042,  146.2226,  175.4671,  70.9708,  153.3674,  180.0000,  71.9375,  161.2662,  180.0000,  72.9042,  170.0787,  180.0000,  73.8625,  179.9101,  180.0000,
11,23,  2,  60.0042,  100.0222,  120.0250,  62.5042,  108.3068,  129.9664,  65.0042,  118.3302,  141.9963,  67.5042,  130.6903,  156.8262,  69.9958,  146.1632,  175.3959,
 6,23,  3,  50.0042,   77.7930,   93.3516,  52.5042,   82.1418,   98.5701,  55.0042,   87.1811,  104.6174,  57.5042,   93.0751,  111.6886,  59.9958,   99.9944,  119.9917,
 6,23,  4,  40.0042,   65.2800,   78.3349,  42.5042,   67.8222,   81.3866,  45.0042,   70.7212,   84.8643,  47.5042,   74.0219,   88.8250,  49.9958,   77.7855,   93.3413,
 6,23,  5,  30.0042,   57.7418,   69.2892,  32.5042,   59.2919,   71.1492,  35.0042,   61.0411,   73.2493,  37.5042,   63.0323,   75.6377,  39.9958,   65.2721,   78.3254,
 6,23,  6,  20.0042,   53.2098,   63.8518,  22.5042,   54.1218,   64.9461,  25.0042,   55.1756,   66.2098,  27.5042,   56.3765,   67.6509,  29.9958,   57.7324,   69.2789,
 6,23,  7,  10.0042,   50.7764,   60.9308,  12.5042,   51.2194,   61.4625,  15.0042,   51.7694,   62.1224,  17.5042,   52.4272,   62.9126,  19.9958,   53.2072,   63.8487,
13,23,  8,   0.0042,   50.0000,   60.0000,   2.5042,   50.0517,   60.0612,   5.0042,   50.1959,   60.2342,   7.5042,   50.4319,   60.5183,   9.9958,   50.7710,   60.9252,
13,23,  9,  -9.9958,   50.7710,   60.9252,  -7.5042,   50.4319,   60.5183,  -5.0042,   50.1959,   60.2342,  -2.5042,   50.0517,   60.0612,  -0.0042,   50.0000,   60.0000,
13,23, 10, -19.9958,   53.2072,   63.8487, -17.5042,   52.4272,   62.9126, -15.0042,   51.7694,   62.1224, -12.5042,   51.2194,   61.4625, -10.0042,   50.7764,   60.9308,
13,23, 11, -29.9958,   57.7324,   69.2789, -27.5042,   56.3765,   67.6509, -25.0042,   55.1756,   66.2098, -22.5042,   54.1218,   64.9461, -20.0042,   53.2098,   63.8518,
12,23, 15, -69.9958,  146.1632,  175.3959, -67.5042,  130.6903,  156.8262, -65.0042,  118.3302,  141.9963, -62.5042,  108.3068,  129.9664, -60.0042,  100.0222,  120.0250,
12,23, 16, -73.8625,  179.9101,  180.0000, -72.9042,  170.0787,  180.0000, -71.9375,  161.2662,  180.0000, -70.9708,  153.3674,  180.0000, -70.0042,  146.2226,  175.4671,
11,24,  2,  60.0042,  120.0250,  140.0278,  62.5042,  129.9664,  151.6260,  65.0042,  141.9963,  165.6623,  67.5042,  156.8262,  180.0000,  69.9958,  175.3959,  180.0000,
 6,24,  3,  50.0042,   93.3516,  108.9102,  52.5042,   98.5701,  114.9985,  55.0042,  104.6174,  122.0536,  57.5042,  111.6886,  130.3020,  59.9958,  119.9917,  139.9889,
 7,24,  4,  40.0042,   78.3349,   91.3898,  42.5042,   81.3866,   94.9510,  45.0042,   84.8643,   99.0074,  47.5042,   88.8250,  103.6281,  49.9958,   93.3413,  108.8971,
 7,24,  5,  30.0042,   69.2892,   80.8367,  32.5042,   71.1492,   83.0066,  35.0042,   73.2493,   85.4575,  37.5042,   75.6377,   88.2431,  39.9958,   78.3254,   91.3788,
 7,24,  6,  20.0042,   63.8518,   74.4938,  22.5042,   64.9461,   75.7705,  25.0042,   66.2098,   77.2440,  27.5042,   67.6509,   78.9253,  29.9958,   69.2789,   80.8254,
 7,24,  7,  10.0042,   60.9308,   71.0853,  12.5042,   61.4625,   71.7055,  15.0042,   62.1224,   72.4754,  17.5042,   62.9126,   73.3981,  19.9958,   63.8487,   74.4901,
13,24, 12, -39.9958,   78.3254,   91.3788, -37.5042,   75.6377,   88.2431, -35.0042,   73.2493,   85.4575, -32.5042,   71.1492,   83.0066, -30.0042,   69.2892,   80.8367,
13,24, 15, -69.9958,  175.3959,  180.0000, -67.5042,  156.8262,  180.0000, -65.0042,  141.9963,  165.6623, -62.5042,  129.9664,  151.6260, -60.0042,  120.0250,  140.0278,
11,25,  2,  60.0042,  140.0278,  160.0306,  61.7792,  148.0321,  169.1796,  63.5542,  157.1901,  179.6445,  65.3292,  167.7019,  180.0000,  67.1042,  179.9357,  180.0000,
 6,25,  3,  50.0042,  108.9102,  124.4688,  52.5042,  114.9985,  131.4268,  55.0042,  122.0536,  139.4898,  57.5042,  130.3020,  148.9155,  59.9958,  139.9889,  159.9861,
 1,25,  4,  40.0042,   91.3898,  104.4447,  42.5042,   94.9510,  108.5154,  45.0042,   99.0074,  113.1504,  47.5042,  103.6281,  118.4313,  49.9958,  108.8971,  124.4528,
 1,25,  5,  30.0042,   80.8367,   92.3841,  32.5042,   83.0066,   94.8640,  35.0042,   85.4575,   97.6657,  37.5042,   88.2431,  100.8485,  39.9958,   91.3788,  104.4321,
 7,25,  6,  20.0042,   74.4938,   85.1357,  22.5042,   75.7705,   86.5948,  25.0042,   77.2440,   88.2782,  27.5042,   78.9253,   90.1997,  29.9958,   80.8254,   92.3718,
 7,25,  7,  10.0042,   71.0853,   81.2397,  12.5042,   71.7055,   81.9485,  15.0042,   72.4754,   82.8284,  17.5042,   73.3981,   83.8835,  19.9958,   74.4901,   85.1315,
 7,25,  8,   0.0042,   70.0000,   80.0000,   2.5042,   70.0707,   80.0802,   5.0042,   70.2726,   80.3109,   7.5042,   70.6047,   80.6911,   9.9958,   71.0794,   81.2335,
13,25,  9,  -9.9958,   71.0794,   81.2335,  -7.5042,   70.6047,   80.6911,  -5.0042,   70.2726,   80.3109,  -2.5042,   70.0707,   80.0802,  -0.0042,   70.0000,   80.0000,
11,26,  2,  60.0042,  160.0306,  180.0000,  60.9042,  164.5252,  180.0000,  61.8042,  169.3293,  180.0000,  62.7042,  174.4576,  180.0000,  63.6042,  179.9625,  180.0000,
 6,26,  3,  50.0042,  124.4688,  140.0274,  52.5042,  131.4268,  147.8552,  55.0042,  139.4898,  156.9261,  57.5042,  148.9155,  167.5290,  59.9958,  159.9861,  179.9833,
 7,26,  4,  40.0042,  104.4447,  117.4996,  42.5042,  108.5154,  122.0799,  45.0042,  113.1504,  127.2935,  47.5042,  118.4313,  133.2344,  49.9958,  124.4528,  140.0086,
 7,26,  5,  30.0042,   92.3841,  103.9315,  32.5042,   94.8640,  106.7214,  35.0042,   97.6657,  109.8740,  37.5042,  100.8485,  113.4539,  39.9958,  104.4321,  117.4854,
 7,26,  6,  20.0042,   85.1357,   95.7777,  22.5042,   86.5948,   97.4192,  25.0042,   88.2782,   99.3124,  27.5042,   90.1997,  101.4740,  29.9958,   92.3718,  103.9183,
 7,26,  7,  10.0042,   81.2397,   91.3941,  12.5042,   81.9485,   92.1916,  15.0042,   82.8284,   93.1814,  17.5042,   83.8835,   94.3689,  19.9958,   85.1315,   95.7730,
 7,26,  8,   0.0042,   80.0000,   90.0000,   2.5042,   80.0802,   90.0897,   5.0042,   80.3109,   90.3493,   7.5042,   80.6911,   90.7775,   9.9958,   81.2335,   91.3877,
 6,27,  3,  50.0042,  140.0274,  155.5860,  52.5042,  147.8552,  164.2835,  55.0042,  156.9261,  174.3623,  57.5042,  167.5290,  180.0000,  59.9958,  179.9833,  180.0000,
 7,27,  4,  40.0042,  117.4996,  130.5545,  42.5042,  122.0799,  135.6443,  45.0042,  127.2935,  141.4366,  47.5042,  133.2344,  148.0376,  49.9958,  140.0086,  155.5644,
 7,27,  5,  30.0042,  103.9315,  115.4789,  32.5042,  106.7214,  118.5788,  35.0042,  109.8740,  122.0822,  37.5042,  113.4539,  126.0594,  39.9958,  117.4854,  130.5388,
 7,27,  6,  20.0042,   95.7777,  106.4197,  22.5042,   97.4192,  108.2435,  25.0042,   99.3124,  110.3466,  27.5042,  101.4740,  112.7484,  29.9958,  103.9183,  115.4648,
 7,27,  7,  10.0042,   91.3941,  101.5486,  12.5042,   92.1916,  102.4346,  15.0042,   93.1814,  103.5344,  17.5042,   94.3689,  104.8544,  19.9958,   95.7730,  106.4144,
 9,27,  8,   0.0042,   90.0000,  100.0000,   2.5042,   90.0897,  100.0992,   5.0042,   90.3493,  100.3876,   7.5042,   90.7775,  100.8639,   9.9958,   91.3877,  101.5419,
 9,27,  9,  -9.9958,   91.3877,  101.5419,  -7.5042,   90.7775,  100.8639,  -5.0042,   90.3493,  100.3876,  -2.5042,   90.0897,  100.0992,  -0.0042,   90.0000,  100.0000,
13,27, 10, -19.9958,   95.7730,  106.4144, -17.5042,   94.3689,  104.8544, -15.0042,   93.1814,  103.5344, -12.5042,   92.1916,  102.4346, -10.0042,   91.3941,  101.5486,
13,27, 11, -29.9958,  103.9183,  115.4648, -27.5042,  101.4740,  112.7484, -25.0042,   99.3124,  110.3466, -22.5042,   97.4192,  108.2435, -20.0042,   95.7777,  106.4197,
 8,27, 12, -39.9958,  117.4854,  130.5388, -37.5042,  113.4539,  126.0594, -35.0042,  109.8740,  122.0822, -32.5042,  106.7214,  118.5788, -30.0042,  103.9315,  115.4789,
13,27, 14, -59.9958,  179.9833,  180.0000, -57.5042,  167.5290,  180.0000, -55.0042,  156.9261,  174.3623, -52.5042,  147.8552,  164.2835, -50.0042,  140.0274,  155.5860,
 6,28,  3,  50.0042,  155.5860,  171.1446,  51.5625,  160.8579,  176.9437,  53.1208,  166.6281,  180.0000,  54.6792,  172.9660,  180.0000,  56.2458,  179.9850,  180.0000,
 7,28,  4,  40.0042,  130.5545,  143.6094,  42.5042,  135.6443,  149.2087,  45.0042,  141.4366,  155.5796,  47.5042,  148.0376,  162.8407,  49.9958,  155.5644,  171.1202,
 7,28,  5,  30.0042,  115.4789,  127.0263,  32.5042,  118.5788,  130.4361,  35.0042,  122.0822,  134.2904,  37.5042,  126.0594,  138.6648,  39.9958,  130.5388,  143.5921,
 7,28,  6,  20.0042,  106.4197,  117.0616,  22.5042,  108.2435,  119.0679,  25.0042,  110.3466,  121.3808,  27.5042,  112.7484,  124.0228,  29.9958,  115.4648,  127.0113,
 7,28,  7,  10.0042,  101.5486,  111.7030,  12.5042,  102.4346,  112.6777,  15.0042,  103.5344,  113.8874,  17.5042,  104.8544,  115.3398,  19.9958,  106.4144,  117.0559,
 9,28,  8,   0.0042,  100.0000,  110.0000,   2.5042,  100.0992,  110.1087,   5.0042,  100.3876,  110.4259,   7.5042,  100.8639,  110.9503,   9.9958,  101.5419,  111.6961,
 9,28,  9,  -9.9958,  101.5419,  111.6961,  -7.5042,  100.8639,  110.9503,  -5.0042,  100.3876,  110.4259,  -2.5042,  100.0992,  110.1087,  -0.0042,  100.0000,  110.0000,
13,28, 10, -19.9958,  106.4144,  117.0559, -17.5042,  104.8544,  115.3398, -15.0042,  103.5344,  113.8874, -12.5042,  102.4346,  112.6777, -10.0042,  101.5486,  111.7030,
 8,28, 11, -29.9958,  115.4648,  127.0113, -27.5042,  112.7484,  124.0228, -25.0042,  110.3466,  121.3808, -22.5042,  108.2435,  119.0679, -20.0042,  106.4197,  117.0616,
 8,28, 12, -39.9958,  130.5388,  143.5921, -37.5042,  126.0594,  138.6648, -35.0042,  122.0822,  134.2904, -32.5042,  118.5788,  130.4361, -30.0042,  115.4789,  127.0263,
 8,28, 13, -49.9958,  155.5644,  171.1202, -47.5042,  148.0376,  162.8407, -45.0042,  141.4366,  155.5796, -42.5042,  135.6443,  149.2087, -40.0042,  130.5545,  143.6094,
13,28, 14, -56.2458,  179.9850,  180.0000, -54.6792,  172.9660,  180.0000, -53.1208,  166.6281,  180.0000, -51.5625,  160.8579,  176.9437, -50.0042,  155.5860,  171.1446,
13,29,  3,  50.0042,  171.1446,  180.0000,  50.5792,  173.2283,  180.0000,  51.1542,  175.3764,  180.0000,  51.7292,  177.6051,  180.0000,  52.3208,  179.9591,  180.0000,
 7,29,  5,  30.0042,  127.0263,  138.5737,  32.5042,  130.4361,  142.2935,  35.0042,  134.2904,  146.4986,  37.5042,  138.6648,  151.2702,  39.9958,  143.5921,  156.6454,
 7,29,  6,  20.0042,  117.0616,  127.7036,  22.5042,  119.0679,  129.8923,  25.0042,  121.3808,  132.4150,  27.5042,  124.0228,  135.2971,  29.9958,  127.0113,  138.5578,
 9,29,  7,  10.0042,  111.7030,  121.8574,  12.5042,  112.6777,  122.9207,  15.0042,  113.8874,  124.2404,  17.5042,  115.3398,  125.8252,  19.9958,  117.0559,  127.6973,
 9,29,  8,   0.0042,  110.0000,  120.0000,   2.5042,  110.1087,  120.1182,   5.0042,  110.4259,  120.4643,   7.5042,  110.9503,  121.0367,   9.9958,  111.6961,  121.8503,
 9,29,  9,  -9.9958,  111.6961,  121.8503,  -7.5042,  110.9503,  121.0367,  -5.0042,  110.4259,  120.4643,  -2.5042,  110.1087,  120.1182,  -0.0042,  110.0000,  120.0000,
 8,29, 10, -19.9958,  117.0559,  127.6973, -17.5042,  115.3398,  125.8252, -15.0042,  113.8874,  124.2404, -12.5042,  112.6777,  122.9207, -10.0042,  111.7030,  121.8574,
 8,29, 11, -29.9958,  127.0113,  138.5578, -27.5042,  124.0228,  135.2971, -25.0042,  121.3808,  132.4150, -22.5042,  119.0679,  129.8923, -20.0042,  117.0616,  127.7036,
 8,29, 12, -39.9958,  143.5921,  156.6454, -37.5042,  138.6648,  151.2702, -35.0042,  134.2904,  146.4986, -32.5042,  130.4361,  142.2935, -30.0042,  127.0263,  138.5737,
 8,29, 13, -49.9958,  171.1202,  180.0000, -47.5042,  162.8407,  177.6438, -45.0042,  155.5796,  169.7227, -42.5042,  149.2087,  162.7732, -40.0042,  143.6094,  156.6643,
13,30,  5,  30.0042,  138.5737,  150.1211,  32.5042,  142.2935,  154.1509,  35.0042,  146.4986,  158.7068,  37.5042,  151.2702,  163.8756,  39.9958,  156.6454,  169.6987,
13,30,  6,  20.0042,  127.7036,  138.3456,  22.5042,  129.8923,  140.7166,  25.0042,  132.4150,  143.4492,  27.5042,  135.2971,  146.5715,  29.9958,  138.5578,  150.1042,
 9,30,  7,  10.0042,  121.8574,  132.0118,  12.5042,  122.9207,  133.1637,  15.0042,  124.2404,  134.5934,  17.5042,  125.8252,  136.3107,  19.9958,  127.6973,  138.3388,
 9,30,  8,   0.0042,  120.0000,  130.0000,   2.5042,  120.1182,  130.1277,   5.0042,  120.4643,  130.5026,   7.5042,  121.0367,  131.1230,   9.9958,  121.8503,  132.0045,
 9,30,  9,  -9.9958,  121.8503,  132.0045,  -7.5042,  121.0367,  131.1230,  -5.0042,  120.4643,  130.5026,  -2.5042,  120.1182,  130.1277,  -0.0042,  120.0000,  130.0000,
 8,30, 10, -19.9958,  127.6973,  138.3388, -17.5042,  125.8252,  136.3107, -15.0042,  124.2404,  134.5934, -12.5042,  122.9207,  133.1637, -10.0042,  121.8574,  132.0118,
 8,30, 11, -29.9958,  138.5578,  150.1042, -27.5042,  135.2971,  146.5715, -25.0042,  132.4150,  143.4492, -22.5042,  129.8923,  140.7166, -20.0042,  127.7036,  138.3456,
 8,30, 12, -39.9958,  156.6454,  169.6987, -37.5042,  151.2702,  163.8756, -35.0042,  146.4986,  158.7068, -32.5042,  142.2935,  154.1509, -30.0042,  138.5737,  150.1211,
 8,30, 13, -48.1792,  179.9625,  180.0000, -46.1292,  173.1581,  180.0000, -44.0875,  167.0641,  180.0000, -42.0458,  161.5966,  175.0625, -40.0042,  156.6643,  169.7193,
13,31,  6,  20.0042,  138.3456,  148.9875,  22.5042,  140.7166,  151.5410,  25.0042,  143.4492,  154.4834,  27.5042,  146.5715,  157.8459,  29.9958,  150.1042,  161.6507,
13,31,  7,  10.0042,  132.0118,  142.1663,  12.5042,  133.1637,  143.4068,  15.0042,  134.5934,  144.9464,  17.5042,  136.3107,  146.7961,  19.9958,  138.3388,  148.9802,
13,31,  8,   0.0042,  130.0000,  140.0000,   2.5042,  130.1277,  140.1372,   5.0042,  130.5026,  140.5410,   7.5042,  131.1230,  141.2094,   9.9958,  132.0045,  142.1587,
 9,31,  9,  -9.9958,  132.0045,  142.1587,  -7.5042,  131.1230,  141.2094,  -5.0042,  130.5026,  140.5410,  -2.5042,  130.1277,  140.1372,  -0.0042,  130.0000,  140.0000,
 8,31, 10, -19.9958,  138.3388,  148.9802, -17.5042,  136.3107,  146.7961, -15.0042,  134.5934,  144.9464, -12.5042,  133.1637,  143.4068, -10.0042,  132.0118,  142.1663,
 1,31, 11, -29.9958,  150.1042,  161.6507, -27.5042,  146.5715,  157.8459, -25.0042,  143.4492,  154.4834, -22.5042,  140.7166,  151.5410, -20.0042,  138.3456,  148.9875,
 8,31, 12, -39.9958,  169.6987,  180.0000, -37.5042,  163.8756,  176.4810, -35.0042,  158.7068,  170.9151, -32.5042,  154.1509,  166.0083, -30.0042,  150.1211,  161.6685,
 8,31, 13, -43.7542,  179.9769,  180.0000, -42.8042,  177.1945,  180.0000, -41.8708,  174.5836,  180.0000, -40.9375,  172.0905,  180.0000, -40.0042,  169.7193,  180.0000,
13,32,  7,  10.0042,  142.1663,  152.3207,  12.5042,  143.4068,  153.6498,  15.0042,  144.9464,  155.2994,  17.5042,  146.7961,  157.2816,  19.9958,  148.9802,  159.6216,
13,32,  8,   0.0042,  140.0000,  150.0000,   2.5042,  140.1372,  150.1467,   5.0042,  140.5410,  150.5793,   7.5042,  141.2094,  151.2958,   9.9958,  142.1587,  152.3129,
 9,32,  9,  -9.9958,  142.1587,  152.3129,  -7.5042,  141.2094,  151.2958,  -5.0042,  140.5410,  150.5793,  -2.5042,  140.1372,  150.1467,  -0.0042,  140.0000,  150.0000,
 9,32, 10, -19.9958,  148.9802,  159.6216, -17.5042,  146.7961,  157.2816, -15.0042,  144.9464,  155.2994, -12.5042,  143.4068,  153.6498, -10.0042,  142.1663,  152.3207,
13,32, 11, -29.9958,  161.6507,  173.1972, -27.5042,  157.8459,  169.1202, -25.0042,  154.4834,  165.5176, -22.5042,  151.5410,  162.3653, -20.0042,  148.9875,  159.6295,
 8,32, 12, -38.9375,  179.9893,  180.0000, -36.7042,  174.6262,  180.0000, -34.4708,  169.8211,  180.0000, -32.2375,  165.5172,  177.3399, -30.0042,  161.6685,  173.2159,
13,33,  7,  10.0042,  152.3207,  162.4751,  12.5042,  153.6498,  163.8928,  15.0042,  155.2994,  165.6525,  17.5042,  157.2816,  167.7670,  19.9958,  159.6216,  170.2631,
13,33,  8,   0.0042,  150.0000,  160.0000,   2.5042,  150.1467,  160.1562,   5.0042,  150.5793,  160.6176,   7.5042,  151.2958,  161.3822,   9.9958,  152.3129,  162.4671,
 9,33,  9,  -9.9958,  152.3129,  162.4671,  -7.5042,  151.2958,  161.3822,  -5.0042,  150.5793,  160.6176,  -2.5042,  150.1467,  160.1562,  -0.0042,  150.0000,  160.0000,
 9,33, 10, -19.9958,  159.6216,  170.2631, -17.5042,  157.2816,  167.7670, -15.0042,  155.2994,  165.6525, -12.5042,  153.6498,  163.8928, -10.0042,  152.3207,  162.4751,
 9,33, 11, -29.9958,  173.1972,  180.0000, -27.5042,  169.1202,  180.0000, -25.0042,  165.5176,  176.5518, -22.5042,  162.3653,  173.1897, -20.0042,  159.6295,  170.2715,
13,34,  7,  10.0042,  162.4751,  172.6296,  12.5042,  163.8928,  174.1359,  15.0042,  165.6525,  176.0055,  17.5042,  167.7670,  178.2524,  19.9958,  170.2631,  180.0000,
13,34,  8,   0.0042,  160.0000,  170.0000,   2.5042,  160.1562,  170.1657,   5.0042,  160.6176,  170.6560,   7.5042,  161.3822,  171.4686,   9.9958,  162.4671,  172.6213,
 9,34,  9,  -9.9958,  162.4671,  172.6213,  -7.5042,  161.3822,  171.4686,  -5.0042,  160.6176,  170.6560,  -2.5042,  160.1562,  170.1657,  -0.0042,  160.0000,  170.0000,
 9,34, 10, -19.9958,  170.2631,  180.0000, -17.5042,  167.7670,  178.2524, -15.0042,  165.6525,  176.0055, -12.5042,  163.8928,  174.1359, -10.0042,  162.4751,  172.6296,
13,35,  8,   0.0042,  170.0000,  180.0000,   2.5042,  170.1657,  180.0000,   5.0042,  170.6560,  180.0000,   7.5042,  171.4686,  180.0000,   9.9958,  172.6213,  180.0000,
13,35,  9,  -9.9958,  172.6213,  180.0000,  -7.5042,  171.4686,  180.0000,  -5.0042,  170.6560,  180.0000,  -2.5042,  170.1657,  180.0000,  -0.0042,  170.0000,  180.0000,
13,35, 10, -19.1792,  179.9912,  180.0000, -16.8792,  177.6574,  180.0000, -14.5875,  175.6687,  180.0000, -12.2958,  173.9956,  180.0000, -10.0042,  172.6296,  180.0000

};

#endif	/* end of land_tile_tbl.h */
