/* start of lst_1dy_data.h */

#ifndef lst_1dy_data_h
#define	lst_1dy_data_h

/*****************************************************************************
!C-INC

!Description:

  Header file for daily L2 and L3 LST products

!Input Parameters: None

!Output Parameters: None
  
$Log: lst_1dy_data.h, v $
 *
 * Revision V5.1.1, 2005/09/15           G. Fireman
 *	corresponds to V5.1.3 mod11_lst2A1.c
 *	changed Latitude & Longitude 2nd dim from 270 to 271
 * Revision V5.1.0, 2005/05/21 14:31     wan
 *	corresponds to V5.1.0 mod11_lst2A1.c
 *	use the MOD_Swath_Snow to update snow_cv[0].name
 * Revision V5.0.2, 2005/01/31 16:50     wan
 *	corresponds to V5.0.2 updata_for_lst.h
 *	change  TILE_ZDIM_UPD    360	to TILE_ZDIM_UPD    512
 *	delete  TILE_YDIM_6KM_EXT
 *	_FillValue undefined if fillv = -1
 * Revision V5.0.1, 2004/11/11		collins
 *	change snow_cv to snow_cv1 and add snow_cv2 so that that code could
 *	work with old or new MOD10_L2
 * Revision V5.0.0, 2004/06/11 12:07     wan
 *	corresponds to V5.0.0 updata_for_lst.h (6x6 1km-grids)
 *	change	TILE_XDIM_5KM    240	to TILE_XDIM_6KM    200
 *	change	TILE_YDIM_5KM    240	to TILE_YDIM_6KM    200
 *	change	TILE_ZDIM_UPD    200 (int32)  to TILE_ZDIM_UPD    360 (uint16)
 *	add	TILE_YDIM_6KM_EXT 230
 * Revision 4.2.0 2002/10/12  11:58     Z. Wan
 *	to add QC_Emis (increase NSD_LST_6KM_L3 to 17 from 16)
 * Revision 4.0.0 2002/04/24  11:46     Z. Wan
 *	to add SDS for MOD43B1
 *	to be used with v4.0.0 update_for_lst.h (N_VIEW_ANGS set to 5)
 * Revision 3.0.3 2001/10/01  18:11     Z. Wan
 *	to read short SensorAzimuth & SolarAzimuth (scale_factor 0.01) in MOD03	
 * Revision 3.0.0 2001/05/04  09:21     Z. Wan
 *	The size of TILE_ZDIM_UPD was increased to 128.
 *	SDS Emis_33 was deleted from the 5km L3 LST product.
 * Revision V2.5.1  2001/03/26	19:42  Z. Wan
 *	To change the scale from 0.0004 to 0.0005 in cal_1km_l3[10] & [11],
 *	 for Clear_day_cov & Clear_nit_cov in the 1km L3 LST product.	 
 * Revision V2.3.6  2001/03/13	16:29  Z. Wan
 *	To change the scale from 0.0001 to 0.0004 in cal_1km_l3[10] & [11],
 *	 for Clear_day_cov & Clear_nit_cov in the 1km L3 LST product.	 
 * Revision V2.3.2  2000/12/09	09:54  Z. Wan
 *	To change the lower boundary of the valid range to 1 from 0 for
 *	 Columns_per_Global_Grid_Row in lparam_1km_l3[] & lparam_5km_l3[].
 * Revision V2.2.20 2000/09/14	22:44  Z. Wan
 *	To add two SDSs to the MOD11B1 output,
 *	 one is LST_Day_5km_Aggregated_from_1km, another is
 *	 LST_Night_5km_Aggregated_from_1km.
 * Revision V2.2.5 2000/03/19 15:40  Z. Wan
 *	also use the SDS Water_Vapor in MOD07
 * Revision V2.1 1999/12/29  23:29  wan
 * add Land_Cover_Type_QC to land_cv
 * Revision V2.01 1997/11/24  18:13:23  wan
 * Revision V2.0  1997/09/27  18:14:01  wan
 * Revision V1.1  1996/09/21  16:02:41  wan
 * Initial revision
 *
$Id: lst_1dy_data.h, v V2.0 1997/09/27 18:14:01 wan Exp wan $

!Revision History:

!Team-unique Header:
  This software has been created by MODIS Science Team member Zhengming Wan
  for the National Aeronautics and Space Administration, Goddard Space
  Flight Center, under contract NAS5-31370.

!References and Credits:

	Written by Zhengming Wan
	ICESS
	University of California
	Santa Barbara, CA 93106

	wan@icess.ucsb.edu

!Design Notes:

!END
*****************************************************************************/

#include "hdf.h"
#include "mfhdf.h"

#define MAX_N_DAYS_PER_CYCLE 2	/* maximum number of days in one LST
				   processing cycle */

#define CLD_BIT	      02  /* used in LST QA flag for cloudy pixels */
#define SEA_BIT	      03  /* used in LST QA flag for ocean pixels */

#define NSD_LST_L2     9   /* number of parameters in the 1km resolution L2 */
#define NSD_LST_1KM_L3 12  /* number of parameters in the 1km resolution L3
			   product retrieved by the split-window LST method */
#define NSD_LST_6KM_L3 18  /* number of parameters in the 6km resolution L3
			   product retrieved by the day/night LST algorithm 
			   plus two aggregated from the 1km LST product */
#define NSD_MOD03_GEO  9   /* number of SDSs read from the MOD03 product */
#define NSD_MOD07_PROF 4   /* number of SDSs read from the MOD07_L2 product */

#define GLGRID_UL_X	-20015109.354	/* global grid upper left corner */
#define GLGRID_UL_Y	 10007554.677	/* global grid upper left corner */
#define GLGRID_SZ	 926.62543305	/* grid cell size */
#define TILE_XDIM	 1200		/* number of columns in a tile */
#define TILE_YDIM	 1200		/* number of rows in a tile */
#define SPHERE_CODE	 -1
#define TILE_XDIM_6KM	 200	    /* number of columns in a 6km LST tile */
#define TILE_YDIM_6KM	 200	    /* number of rows in a 6km LST tile */
#define TILE_ZDIM_UPD	 512	    /* 16 x 32 blocks of uint16/int16 data */

/* Output parameters for data structure */

typedef struct {
  char *name;		/* name of the parameter */
  int32 type;		/* parameter HDF data type */
  char *long_name;      /* long name */
  char *units;          /* units */
  float32 vrange[2]; /* in order to cover ranges for uint8, uint16, float32 */
  float32 fillv;     /* in order to cover ranges for uint8, uint16, float32 */
} lparameter_t;

/* L2 LST Output parameters definition */

static lparameter_t lparam_lst_l2[NSD_LST_L2] = {

 {"LST", DFNT_UINT16, "Land-surface Temperature", "K", 7500, 65535, 0},
 {"QC", DFNT_UINT16, "Quality control for daytime LST and emissivity",
"none", 0, 65535, -1},
 {"Error_LST", DFNT_UINT8, "Land-surface Temperature Error", "K",1,255, 0},
 {"Emis_31", DFNT_UINT8, "Band 31 emissivity", "none", 1, 255, 0 },
 {"Emis_32", DFNT_UINT8, "Band 32 emissivity", "none", 1, 255, 0 },
 {"View_angle", DFNT_UINT8, "zenith angle of MODIS viewing at the pixel",
"deg", 0, 180, 255 },
 {"View_time", DFNT_UINT8, "Time of Land-surface Temperature observation",
"hrs", 0, 240, 255 },
 {"Latitude", DFNT_FLOAT32, "Latitude of every 5 scan lines and 5 pixels",
"degree", -90.0, 90.0, -999.9 },
 {"Longitude", DFNT_FLOAT32, "Longitude of every 5 scan lines and 5 pixels",
"degree", -180.0, 180.0, -999.9 },

};

/* 1km L3 LST Output parameters definition */

static lparameter_t lparam_1km_l3[NSD_LST_1KM_L3] = {

 {"LST_Day_1km", DFNT_UINT16,
"Daily daytime 1km grid Land-surface Temperature", "K", 7500, 65535, 0},
 {"QC_Day", DFNT_UINT8,
"Quality control for daytime LST and emissivity", "none", 0, 255, -1},
 {"Day_view_time", DFNT_UINT8,
"Time of daytime Land-surface Temperature observation", "hrs", 0, 240, 255 },
 {"Day_view_angl", DFNT_UINT8,
"View zenith angle of daytime Land-surface Temperature", "deg", 0, 130, 255 },
 {"LST_Night_1km", DFNT_UINT16,
"Daily nighttime 1km grid Land-surface Temperature", "K", 7500, 65535, 0},
 {"QC_Night", DFNT_UINT8,
"Quality control for nighttime LST and emissivity", "none", 0, 255, -1},
 {"Night_view_time", DFNT_UINT8,
"Time of nighttime Land-surface Temperature observation", "hrs", 0, 240, 255},
 {"Night_view_angl", DFNT_UINT8,
"View zenith angle of nighttime Land-surface Temperature", "deg", 0, 130, 255},

 {"Emis_31", DFNT_UINT8, "Band 31 emissivity", "none", 1, 255, 0 },
 {"Emis_32", DFNT_UINT8, "Band 32 emissivity", "none", 1, 255, 0 },

 {"Clear_day_cov",DFNT_UINT16,"day clear-sky coverage","none", 1, 65535, 0 },
 {"Clear_nit_cov",DFNT_UINT16,"night clear-sky coverage","none", 1, 65535, 0 },

};

/* 6km L3 LST Output parameters definition */

static lparameter_t lparam_6km_l3[NSD_LST_6KM_L3] = {
 {"LST_Day_6km", DFNT_UINT16,
"Daily daytime 6km grid Land-surface Temperature", "K", 7500, 65535, 0},
 {"QC_Day", DFNT_UINT8,
"Quality control for daytime LST and emissivity", "none", 0, 255, -1},
 {"Day_view_time", DFNT_UINT8,
"Time of daytime Land-surface Temperature observation", "hrs", 0,120, 255 },
 {"Day_view_angl", DFNT_UINT8,
"View zenith angle of daytime Land-surface Temperature", "deg", 0,130, 255 },

 {"LST_Night_6km", DFNT_UINT16,
"Daily nighttime 6km grid Land-surface Temperature", "K", 7500, 65535, 0},
 {"QC_Night", DFNT_UINT8,
"Quality control for nighttime LST and emissivity", "none", 0,255, -1},
 {"Night_view_time", DFNT_UINT8,
"Time of nighttime Land-surface Temperature observation", "hrs", 0,120, 255},
 {"Night_view_angl", DFNT_UINT8,
"View zenith angle of nighttime Land-surface Temperature", "deg", 0,130, 255},

 {"Emis_20", DFNT_UINT8, "Band 20 emissivity", "none", 1, 255, 0 },
 {"Emis_22", DFNT_UINT8, "Band 22 emissivity", "none", 1, 255, 0 },
 {"Emis_23", DFNT_UINT8, "Band 23 emissivity", "none", 1, 255, 0 },
 {"Emis_29", DFNT_UINT8, "Band 29 emissivity", "none", 1, 255, 0 },
 {"Emis_31", DFNT_UINT8, "Band 31 emissivity", "none", 1, 255, 0 },
 {"Emis_32", DFNT_UINT8, "Band 32 emissivity", "none", 1, 255, 0 },

 {"LST_Day_6km_Aggregated_from_1km", DFNT_UINT16,
 "Daily daytime 6km grid LST aggregated from 1km", "K", 7500, 65535, 0},
 {"LST_Night_6km_Aggregated_from_1km", DFNT_UINT16,
 "Daily nighttime 6km grid LST aggregated from 1km", "K", 7500, 65535, 0},

 {"QC_Emis", DFNT_UINT8,
 "Quality control for retrieved emissivities", "none", 0,255, -1},

 {"Percent_land_in_grid", DFNT_UINT8,
 "Percentage of Land in the Grid", "none", 1,100, 0},

};

/* 6km update_for_lst parameters definition */

static lparameter_t lparam_upd_lst[1] = {

 { "Update_lst_S", DFNT_UINT16, "update_for_lst data for four view angles", "non", 0, 65536, 0 }, 

};

/* Calibration scale and offset constants data structure */

#ifdef TRUE
#undef TRUE
#endif
#ifdef FALSE
#undef FALSE
#endif

typedef enum { FALSE, TRUE } logical_t;

typedef struct {
  int32	sd_type;	/* 2 for temperature, 1 for emissivity, 0 for others */
  logical_t valid;	/* calibration valid for this parameter flag; 
  			 * valid = TRUE */
  float64 scale;		/* scale factor    = sacle_factor */
  float64 offset;		/* additive offset = add_offset */
} cal_t;

/* Definition of the calibration scale and offset constants */

static cal_t cal_lst_l2[NSD_LST_L2] = {
  { 2, TRUE,  0.020, 0.0}, { 0, FALSE, 0.0, 0.0},
  { 2, TRUE,  0.040, 0.0},
  { 1, TRUE,  0.002, 0.490}, { 1, TRUE,  0.002, 0.490},
  { 2, TRUE,  0.500, 0.0}, { 2, TRUE,  0.1, 0.0},
  { 0, FALSE,   1.0, 0.0}, { 0, FALSE,  1.0, 0.0},
};

static cal_t cal_1km_l3[NSD_LST_1KM_L3] = {
  { 2, TRUE,   0.02, 0.0}, { 0, FALSE, 0.0, 0.0},
  { 2, TRUE,   0.10, 0.0}, { 2, TRUE,  1.0, -65.0}, 
  { 2, TRUE,   0.02, 0.0}, { 0, FALSE, 0.0, 0.0},
  { 2, TRUE,   0.10, 0.0}, { 2, TRUE,  1.0, -65.0},
  { 1, TRUE,  0.002, 0.49}, { 1, TRUE, 0.002, 0.49},
  { 2, TRUE,  0.0005, 0.0}, { 2, TRUE, 0.0005, 0.0},
};

static cal_t cal_6km_l3[NSD_LST_6KM_L3] = {
  { 2, TRUE,   0.02, 0.0}, { 0, FALSE, 0.0, 0.0},
  { 2, TRUE,    0.2, 0.0}, { 2, TRUE,  1.0, -65.0},
  { 2, TRUE,   0.02, 0.0}, { 0, FALSE, 0.0, 0.0},
  { 2, TRUE,    0.2, 0.0}, { 2, TRUE,  1.0, -65.0},
  { 1, TRUE,  0.002, 0.49}, { 1, TRUE,  0.002, 0.49},
  { 1, TRUE,  0.002, 0.49}, { 1, TRUE,  0.002, 0.49},
  { 1, TRUE,  0.002, 0.49}, { 1, TRUE,  0.002, 0.49},
  { 2, TRUE,   0.02, 0.0}, { 2, TRUE,   0.02, 0.0},
  { 0, FALSE, 0.0, 0.0}, { 0, FALSE, 0.0, 0.0},
};

/* SD variable structure */

typedef struct {
	char	*name;
	char	*gname;
	char	*type;
	long int	rank;
	long int	dims[2];
	float64	scale;
	float64	offset;
} sds_t;

/* SDs for geoloc L1A */

#define SCAN_RATE  20.3				/* mirrow scan rate 20.3 rpm */
#define DSAMP_TIME 0.000667			/* seconds per sample */
					/* 60 / SCAN_RATE * 110 / 360 / 1354 */

#define	EV_TIME(x, j) (x + j * DSAMP_TIME)	/* x is EV start time */
						/* j is pixel number */

/* SDs for geoloc 1A */

static sds_t geo_1a[NSD_MOD03_GEO] = {

	{ "Height",       "\0", "int16",  2, 2030,  1354, 0.001, 0. },
	{ "SensorZenith", "\0", "int16",  2, 2030,  1354,  0.01, 0. },
	{ "SolarZenith",  "\0", "int16",  2, 2030,  1354,  0.01, 0. },
	{ "Latitude",     "\0", "float32",2, 2030,  1354,  1.0, 0.0 },
	{ "Longitude",    "\0", "float32",2, 2030,  1354,  1.0, 0.0 },
	{ "Land/SeaMask", "\0", "byte",   2, 2030,  1354,  1.0, 0.0 },
	{ "EV start time","\0", "float64",1, 2030,     0,  1.0, 0.0 },
	{ "SensorAzimuth", "\0", "int16",  2, 2030,  1354, 0.01, 0. },
	{ "SolarAzimuth",  "\0", "int16",  2, 2030,  1354, 0.01, 0. },
};

/* SDS for MOD43B1 or MOD43B1C */

char	brdf_param[] = "BRDF_Albedo_Parameters";
char	brdf_grpnm[] = "\0";
char	brdf_qa[] = "BRDF_Albedo_Quality";
long int brdf_p_dims[4] = { 1200, 1200, 1, 3 };		/* for band 7 */
long int brdf_q_dims[3] = { 1200, 1200, 1 };
long int brdf_p_dims_6km[4] = { 200, 200, 1, 3 };	/* for band 7 */
long int brdf_q_dims_6km[3] = { 200, 200, 1 }; 	/* bits 24-27 in QC_Words #2
						   for band 7
						   0-7 full inversion
						   8-10 magnitude inversion
						   11 Bus-in DB parameters
						   15 Fill value
						 */

/* SD for CloudMask */

char     cld_arrnm[] = "Cloud_Mask";
char     cld_grpnm[] = "\0";
char     cld_type[] = "byte";
long int cld_dims[3] = { 6, 2030, 1354 };

/* SDs for geoloc in MOD021KM */

static sds_t geo_5pix[2] = {

	{ "Latitude",     "\0", "float32", 2, 406,  271,  1.0, 0.0 },
	{ "Longitude",    "\0", "float32", 2, 406,  271,  1.0, 0.0 },

};

/* SDs for atmospheric profile */

static sds_t mod07_prof[NSD_MOD07_PROF] = {

	{ "Cloud_Mask", "\0", "byte",   2, 406, 270, 1.0, 0.0 },
	{ "Surface_Temperature", "\0", "int16", 2, 406, 270, 0.01, -15000 },
	{ "Surface_Pressure",    "\0", "int16", 2, 406, 270, 0.1, 0.0 },
	{ "Water_Vapor",    "\0", "int16", 2, 406, 270, 0.001, 0.0 },

};
char	dtype_mod07[8];
char	sd_t_prof[] = "Retrieved_Temperature_Profile";
char	sd_w_prof[] = "Retrieved_Moisture_Profile";
char	sd_qa_prof[] = "Quality_Assurance";
char	prof_grpnm[] = "\0";
long int dims_prof[3] = { 14, 406, 270 };
long int dims_qa_prof[3] = { 406, 270, 1 };

/* SDs for landcover */

long int	lc_qc_sta[3] = { 0, 0, 0 };
long int	lc_qc_dims[3] = { 1, 1200, 1200 };

static sds_t land_cv[2] = {

	{ "Land_Cover_Type_1", "\0", "byte", 2, 1200, 1200, 1.0, 0. },
	{ "Land_Cover_Type_QC", "\0", "byte", 2, 1200, 1200, 1.0, 0. },

};

/* SDs for snow cover */
/*snow_cv changed to snow_cv1 and added second snow_cv2 so that code could work
with old or new MOD10_L2. Changed by c.collins on 11/11/04*/
/*
static sds_t snow_cv1[1] = {

	{ "Snow Cover",	"\0", "byte", 2, 4060, 2708, 1.0, 0. },

};
static sds_t snow_cv2[1] = {

	{ "Snow_Cover", "\0", "byte", 2, 4060, 2708, 1.0, 0. },

}; */
static sds_t snow_cv[1] = {	/* to be updated with the name in MOD_Swath_Snow */

	{ "Snow_Cover", "\0", "byte", 2, 4060, 2708, 1.0, 0. },

};
char	arrnm_snow[16];
char	dtype_snow[8];

/* SDs for LST L2 & L3 products */

static sds_t lst_l2[NSD_LST_L2] = {

	{ "LST",        "\0", "uint16", 2, 2030, 1354, 0.020, 0.0 },
	{ "QC",         "\0", "uint16", 2, 2030, 1354,   1.0, 0.0 },
	{ "Error_LST",  "\0", "uint8",  2, 2030, 1354, 0.040, 0.0 },
	{ "Emis_31",    "\0", "uint8",  2, 2030, 1354, 0.002, 0.49 },
	{ "Emis_32",    "\0", "uint8",  2, 2030, 1354, 0.002, 0.49 },
	{ "View_angle", "\0", "uint8",  2, 2030, 1354,   0.5, 0.0 },
	{ "View_time",  "\0", "uint8",  2, 2030, 1354,   0.1, 0.0 },
	{ "Latitude",  "\0", "float32", 2,  406,  271,   1.0, 0.0 },
	{ "Longitude", "\0", "float32", 2,  406,  271,   1.0, 0.0 },
};

char	*descrip_lst_l2[NSD_LST_L2] = {
	"Land surface temperature",
	"LST Quality Indicators",
	"Error in land surface temperature",
	"Band 31 emissivity",
	"Band 32 emissivity",
	"MODIS viewing angle",
	"MODIS viewing time",
	"Latitude",
	"Longitude"
};

char	*dataconvt_lst_l2[ 2 * NSD_LST_L2 ] = {
	"LST",		"LST data * scale_factor + add_offset",
	NULL,		NULL,
	"Error_LST",	"Error_LST data * scale_factor + add_offset",
	"Emis_31",	"Emis_31 data * scale_factor + add_offset",
	"Emis_32",	"Emis_32 data * scale_factor + add_offset",
	"View_angle",	"View_angle data * scale_factor + add_offset",
	"View_time",	"View_time data * scale_factor + add_offset",
	NULL,		NULL,
	NULL,		NULL
};

/* SDs for daily LST 1km L3 */

static sds_t lst_1km_l3[NSD_LST_1KM_L3] = {

  { "LST_Day_1km",   "\0", "uint16", 2, 1200, 1200,  0.02, 0.0 },
  { "QC_Day",        "\0", "uint8",  2, 1200, 1200,   1.0, 0.0 },
  { "Day_view_time", "\0", "uint8",  2, 1200, 1200,   0.1, 0.0 },
  { "Day_view_angl", "\0", "uint8",  2, 1200, 1200,   1.0, -65.0 },
  { "LST_Night_1km", "\0", "uint16", 2, 1200, 1200,  0.02, 0.0 },
  { "QC_Night",      "\0", "uint8",  2, 1200, 1200,   1.0, 0.0 },
  { "Night_view_time","\0", "uint8", 2, 1200, 1200,   0.1, 0.0 },
  { "Night_view_angl","\0", "uint8", 2, 1200, 1200,   1.0, -65.0 },
  { "Emis_31",        "\0", "uint8", 2, 1200, 1200,  0.002, 0.49},
  { "Emis_32",        "\0", "uint8", 2, 1200, 1200,  0.002, 0.49},
  { "Clear_day_cov",  "\0", "uint16",2, 1200, 1200,  0.0005, 0.0},
  { "Clear_night_cov","\0", "uint16",2, 1200, 1200,  0.0005, 0.0},
};

char	*descrip_1km_l3[NSD_LST_1KM_L3] = {
	"Daily daytime 1km grid Land-surface Temperature",
	"LST Quality Indicators",
	"MODIS day viewing time",
	"MODIS day viewing angle",
	"Daily nighttime 1km grid Land-surface Temperature",
	"LST Quality Indicators",
	"MODIS night viewing time",
	"MODIS night viewing angle",
	"Band 31 emissivity",
	"Band 32 emissivity",
	"day clear-sky coverage",
	"night clear-sky coverage",
};

char	*dataconvt_1km_l3[ 2 * NSD_LST_1KM_L3 ] = {
	"LST",		"LST data * scale_factor + add_offset",
	NULL,		NULL,
	"View_time",	"View_time data * scale_factor + add_offset",
	"View_angle",	"View_angle data * scale_factor + add_offset",
	"LST",		"LST data * scale_factor + add_offset",
	NULL,		NULL,
	"View_time",	"View_time data * scale_factor + add_offset",
	"View_angle",	"View_angle data * scale_factor + add_offset",
	"Emis_31",	"Emis_31 data * scale_factor + add_offset",
	"Emis_32",	"Emis_32 data * scale_factor + add_offset",
	"day clear_sky_cov","day_clear_sky_cov data * scale_factor + add_offset",
	"night clear_sky_cov","nit_clear_sky_cov data * scale_factor + add_offset",
};

/* SDs for daily LST 6km L3 */

static sds_t lst_6km_l3[NSD_LST_6KM_L3] = {
  { "LST_Day_6km",   "\0", "uint16", 2, 200, 200,  0.02, 0.0 },
  { "QC_Day",        "\0", "uint8",  2, 200, 200,   1.0, 0.0 },
  { "Day_view_time", "\0", "uint8",  2, 200, 200,   0.2, 0.0 },
  { "Day_view_angl", "\0", "uint8",  2, 200, 200,   1.0, -65.0 },
  { "LST_Night_6km", "\0", "uint16", 2, 200, 200,  0.02, 0.0 },
  { "QC_Night",      "\0", "uint8",  2, 200, 200,   1.0, 0.0 },
  { "Night_view_time","\0","uint8",  2, 200, 200,   0.2, 0.0 },
  { "Night_view_angl","\0","uint8",  2, 200, 200,   1.0, -65.0 },
  { "Emis_20",        "\0","uint8",  2, 200, 200, 0.002, 0.49 },
  { "Emis_22",        "\0","uint8",  2, 200, 200, 0.002, 0.49 },
  { "Emis_23",        "\0","uint8",  2, 200, 200, 0.002, 0.49 },
  { "Emis_29",        "\0","uint8",  2, 200, 200, 0.002, 0.49 },
  { "Emis_31",        "\0","uint8",  2, 200, 200, 0.002, 0.49 },
  { "Emis_32",        "\0","uint8",  2, 200, 200, 0.002, 0.49 },
  { "LST_Day_6km_Aggregated_from_1km",   "\0", "uint16", 2, 200, 200, 0.02, 0.0 },
  { "LST_Night_6km_Aggregated_from_1km", "\0", "uint16", 2, 200, 200, 0.02, 0.0 },
  { "QC_Emis",        "\0", "uint8", 2, 200, 200,   1.0, 0.0 },
  { "Percent_land_in_grid",  "\0", "uint8", 2, 200, 200,   1.0, 0.0 },
};

typedef struct {
	char    *name;
	char    *gname;
	char    *type;
	long int        rank;
	long int        dims[3];
	float64 scale;
	float64 offset;
} sds_3d_t;

static sds_3d_t upd_lst_6km[1] = {

 { "Update_lst_S","\0","uint16", 3,TILE_YDIM_6KM,TILE_XDIM_6KM,TILE_ZDIM_UPD, 1.0, 0.0 },

};

char	*descrip_upd_lst_6km[1] = {
	"update_for_lst data for 6 viewing angles",
};

char	*descrip_6km_l3[NSD_LST_6KM_L3] = {
	"Daily daytime 6km grid Land-surface Temperature",
	"LST Quality Indicators",
	"MODIS day viewing time",
	"MODIS day viewing angle",
	"Daily nighttime 6km grid Land-surface Temperature",
	"LST Quality Indicators",
	"MODIS night viewing time",
	"MODIS night viewing angle",
	"Band 20 emissivity",
	"Band 22 emissivity",
	"Band 23 emissivity",
	"Band 29 emissivity",
	"Band 31 emissivity",
	"Band 32 emissivity",
	"Daily daytime 6km grid LST aggregated from 1km",
	"Daily nighttime 6km grid LST aggregated from 1km",
	"Emissivity Quality Indicators",
	"Percentage of Land in the Grid",
};

char	*dataconvt_6km_l3[ 2 * NSD_LST_6KM_L3 ] = {
	"LST",		"LST data * scale_factor + add_offset",
	NULL,		NULL,
	"View_time",	"View_time data * scale_factor + add_offset",
	"View_angle",	"View_angle data * scale_factor + add_offset",
	"LST",		"LST data * scale_factor + add_offset",
	NULL,		NULL,
	"View_time",	"View_time data * scale_factor + add_offset",
	"View_angle",	"View_angle data * scale_factor + add_offset",
	"Emis_20",	"Emis_20 data * scale_factor + add_offset",
	"Emis_22",	"Emis_22 data * scale_factor + add_offset",
	"Emis_23",	"Emis_23 data * scale_factor + add_offset",
	"Emis_29",	"Emis_29 data * scale_factor + add_offset",
	"Emis_31",	"Emis_31 data * scale_factor + add_offset",
	"Emis_32",	"Emis_32 data * scale_factor + add_offset",
	"LST",          "LST data * scale_factor + add_offset",
	"LST",          "LST data * scale_factor + add_offset",
	NULL,           NULL,
	NULL,           NULL,
};

/* structure for granule relation linkage */

typedef struct {

	int32   gran1B_ver_n;
	int32   orbit_n;
	int32   geo1A_ver_n;
	int32   cmask_ver_n;
	int32   aprof_ver_n;
	int32   snow_ver_n;
	char    local_gran_id[64];      /* starting with A[yeardat] */

} gran_link_t;

enum AutoQualFlag	{ PASSED, SUSPECT, FAILED };

typedef struct {

  int32	FirstEntryInStruct; /*+ THIS MUST BE THE FIRST ENTRY IN THE STRUCT +*/

  int32	AllPixelsProcessed;
  int32	NumberOfPixels_LST_Produced;
  int32	DayPixels;
  int32	NightPixels;
  int32	InvalidInput;
  int32	LakePixels;
  int32	LandPixels;
  int32	OceanPixels;
  int32	OutOfRangeData;
  int32	QA_GoodQuality;
  int32	QA_OtherQuality;
  int32	QA_NotProducedCloud;
  int32	QA_NotProducedOther;
  int32	QA_MissingData;
  int32	QA_OutOfBoundsData;

} MET_counts;

#endif /* end of lst_1dy_data.h */
