/*
!C-INC**************************************************************************

!File: obsgrid_lst.h  (Observation Grid Library Header)

!Description: Observation Grid Library Header - structures, types and 
 prototypes for the observation grid library functions.

!Input Parameters:

!Output Parameters:

!Revision History:

   $Log: obsgrid_lst.h,v $
 * Revision 2.3.1 2000/12/02  17:50     Z. Wan
 *	MAX_NOBS was increased to 1020 from 255
 *
 Revision 00.01  1995/01/26
 Robert E. Wolfe
 Original version.
 
 Revision 00.02  1995/03/31
 Robert E. Wolfe
 Updatted prologues.     

 Revision 00.03  1995/06/26
 Virginia L. Kalb
 Changes to add HDF.  See 'obsgrid.c'
 
 Revision 00.04 1995/07/03
 Robert E. Wolfe
 Rework of pointers and calling sequences.  See 'obsgrid.c'.

 Revision 00.05 1995/10/23
 Robert E. Wolfe/MODLAND Support
 1. Modified to store line information for only those lines in memory.
 2. Added routines 'Obs_GetIds' and 'Obs_PutIds' to store and return 
    the granules ids from the grid.
 3. Added routines 'Obs_GetCal' and 'Obs_PutCal' to store and return 
    the calibration information from the grid.

 Revision 00.06 1997/10/03
 Zhengming Wan
 Delete pointer structure and list because it is not necessary for the LST
 process.

 Revision 02.01 1997/11/03
 Zhengming Wan
 Delete Obs_line_t & Obs_parameter_t structures and simplify Obs_gd_t.

!Team-unique Header:

  This software was developed by:
    MODIS Land Science Team for the National Aeronautics and 
    Space Administration, Goddard Space Flight Center, under 
    NASA <contract or task number>

    MODIS Land Science Team Support Group for the National Aeronautics and 
    Space Administration, Goddard Space Flight Center, under 
    NASA Task 92-012-05

!References and Credits:
  
    MODIS Science Team Member:
      Christopher O. Justice
      MODIS Land Science Team           University of Maryland
      justice@kratmos.gsfc.nasa.gov     NASA/GSFC Code 923
      phone: 301-286-7372               Greenbelt, MD 20771

    Developers:
      Robert E. Wolfe
      MODIS Land Team Support Group     Hughes STX
      robert.wolfe@gsfc.nasa.gov        7701 Greenbelt Road, #400
      phone: 301-441-4585               Greenbelt, MD 20770  

      Virginia L. Kalb
      gk@cheshire.gsfc.nasa.gov         NASA/GSFC Code 920.2
      phone: 301-286-2605               Greenbelt, MD 20771

!Design Notes:

!END****************************************************************************
*/

#include "hdf.h"

/* Return Codes */

#define OBS_NORMAL 0
#define OBS_ERROR -1

#define MAX_NOBS 1020

/* Structures */

/* These structures are meant to be 'private' to the observation routines. */

/* Current Grid Location Structure */

typedef struct {
  int32 nobs;             /* Number of observations */
  int32 il;              /* Line number */
  int32 is;              /* Sample number */
/* Z. Wan, it is not necessary for LST process.
  Obs_list_t list[MAX_NOBS]; */  /* List of pointers to observations */
  int16 iobs;             /* Observation number */
} Obs_curr_t;

/* Observation Grid Descriptor */

typedef struct {

  int16 np;		/* Number of parameters per observation */
  int16 nobs;	        /* Total number of observation in entire grid */
  int16 nobs_max; 	/* Maximum number of observations for any pixel */
  int16 ngran;		/* Number of granules */
/* int32 type; */        /* Unique Identifier for Grid Type */
  int32 nl;              /* Number of lines in the grid */
  int32 ns;              /* Number of samples in the grid */

} Obs_gd_t;

/* Types */

typedef Obs_gd_t *Obs_gd_p;
typedef void *Obs_p;

/* Prototypes */

int32 Obs_Free(Obs_gd_p gd, int32 iobs);
Obs_gd_p Obs_CreateGrid (int32 nl, int32 ns, int16 np);
