/* start of pntr_lst.h */

#ifndef pntr_lst_h
#define pntr_lst_h

/******************************************************************************
!C-INC

File: pntr_lst.h

!Description: 
  L2g Pointer Generation Header - structures, types and 
  prototypes for the L2g pointer generation routines.

!Input Parameters: N/A

!Output Parameters: N/A

!Revision History:
  Revision 00.01  1995/09/15
  Ginny Kalb/NASA GSFC
  Original version.

  Revision 00.02  1995/09/15
  Robert E. Wolfe/MODIS Land Team Support
  Extensive rewrite.

  Revision 00.03  1995/10/23
  Robert E. Wolfe/MODIS Land Team Support
  Added capability to generate grids at all three resolutions
  simultaneously.

  Revision 00.04 1995/11/20
  Paul Fisher/SDST
  Added SDP tk/PCF logical number definitions used for all L2G processes.

  Revision 00.10 1997/09/15
  Zhengming Wan, UCSB
  simplified for its use in the LST PGE only.

!Team-unique Header:
  This software was developed by the MODIS Land Science Team Support 
  Group for the National Aeronautics and Space Administration, Goddard 
  Space Flight Center, under NASA Task 92-012-05.

!References and Credits:
    Written by Robert E. Wolfe
               Hughes STX
               robert.wolfe@gsfc.nasa.gov
               phone: 301-441-4585
               
               Hughes STX
               7701 Greenbelt Road, #400
               Greenbelt, MD 20770

  SDP toolkit integration and code modifications by:
               Paul Fisher
               Research and Data Systems Corporation
               GSC/SAIC MODIS Support Office
	       Lanham, MD

!Design Notes:

!END
*****************************************************************************/
 
#include "hdf.h"
#include "mfhdf.h"

/* Observation pointer data structure */

typedef struct {
  /* int granule_pt; */		/* granule id pointer */
  /* int line; */		/* observation line number (1km lines) */
  /* int sample; */		/* observation sample number (1km samples) */
  /* float dline; */	/* delta-line location of center of cell retlative 
  			 * to 1km observation center (scale: 1/64th of 
  			 * a line) */
  /* float dsample; */	/* delta-sample location of center of cell retlative 
  			 * to 1km observation center (units: 1/64th of 
  			 * a sample) */
  float32 obscov;	/* observation coverage; area of intersection between
  			 * obsevation and cell divided by observation area 
  			 * (units: percent) */
  float32 cellcov;	/* cell coverage; area of intersection between
  			 * obsevation and cell divided by cell area
  			 * (units: percent) */
  int32 irow;		/* tile row number */
  int32 ipix;           /* tile pixel number */
  int16 irow_res;		/* row residule at next coarser resolution */
  int16 ipix_res;		/* pixel residule at next coarser resolution */
} obs_t;

/* Geodetic delta-location data structure */

typedef struct {
  float32 dlat, dlon;	/* geodetic delta-latitude and delta-longitude
			 * (radians) */
} dgeo_t;

/* Function Prototypes */

/* Compute the corners of the observation from geolocation information */

void GeoCor_lst(int32 il, int32 is, int32 nl, int32 ns,
             float32 **lon, float32 **lat, dgeo_t *cor);

/* definitions to get parameters from PCF file */
#define MAXGRANULES 288
#define GRANULES_PER_PROCESS 1

#endif

/* end of pntr_lst.h */
