#include <stdio.h>
#include <time.h>
#include "PGS_PC.h"
#include "smfio.h"      /* header file for SMF functionality */
#include "PGS_TD.h"
#include "PGS_SMF.h"
#include "PGS_MODIS_37111.h"  /* MODIS LST SMF seed files */

/* Prototypes */
PGSt_SMF_status current_time_a(char *buffer);

PGSt_SMF_status current_time_a(char *buffer)
/*
!C****************************************************************************

File: timea.c

!Description: This generates the current system time in ASCII Time
Code A format (ref. SDP User's Guide, V5, pp. 6-199 - 6-201).

!Input Parameters:
  char *buffer  Character buffer allocated to TIMECODEASIZE*sizeof(char)

!Output Parameters:
  char *buffer  Character buffer containing current time in ASCII Time Code A

Returns:
  PGSt_SMF_status
    on success:    MODIS_S_SUCCESS
    on error:      MODIS_E_BAD_SYSTEM_TIME
                   MODIS_E_NULL_STRING

!Revision History:
  Revision 1.0  1996/03/08
  Paul Fisher/SDST
  Original Development

  Revision 1.1  1996/03/15
  Paul Fisher/SDST
  Efficiency modification.
  Modified to use only one call to strftime. 

!Team-unique Header:
  This software was developed by:

    MODIS Science Data Support Team for the National Aeronautics and Space 
    Administration, Goddard Space Flight Center, under contract NAS5-32373.

  Developer:
      Paul S. Fisher
      MODIS Science Data Support Team   
      Research and Data Systems Corporation
      SAIC/GSC MODIS Support Office
      7501 Forbes Blvd
      Seabrook, MD 20706  
      fisher@ltpmail.gsfc.nasa.gov     

Design Notes:
  This module returns the current system time in ASCII Time Code A
  format.  It is designed to be used in the SDP Toolkit environment.

  Error handling is performed through the modules smf.c and the
  toolkit SMF seed file MODIS_39501.t.

  As input, this module takes a character string of length
  TIMECODEASIZE, which has been defined in smfio.h, a necessary header
  file for both this module and smf.c

  Upon error, this function will return to the calling module to
  allow exection to continue.

  If 'buffer' contains less than TIMECODEASIZE characters, module
  behavior is undefined.

!END**************************************************************************/
{

  struct tm *curtime=NULL;
  time_t t;

  /* check to make sure buffer has some memory allocated */
  if(!buffer){
    modsmf(MODIS_E_NULL_STRING, "buffer", "current_time_a, timea.c");
    return (MODIS_E_NULL_STRING);
  }

  /* set time */
  if((t=time(NULL))==-1){
    modsmf(MODIS_E_BAD_SYSTEM_TIME, 
	   "Bad time value returned from operating system", 
	   "current_time_a, timea.c");
    return (MODIS_E_BAD_SYSTEM_TIME);
  }

  if(!(curtime=(struct tm *)localtime(&t))){
    modsmf(MODIS_E_BAD_SYSTEM_TIME, 
	   "No time structure filled in call to 'localtime'.", 
	   "current_time_a, timea.c");
    return (MODIS_E_BAD_SYSTEM_TIME);
  }

  /* obtain CCSDS ASCII time code A */
  if((strftime(buffer, TIMECODEASIZE, "%Y-%m-%dT%H:%M:%S.000000Z", curtime))
     ==0){
    modsmf(MODIS_E_BAD_SYSTEM_TIME, "Invalid time structure "
	   "returned from operating system.", 
	   "current_time_a, timea.c");
    return (MODIS_E_BAD_SYSTEM_TIME);
  }

  return(MODIS_S_SUCCESS);
   
}
